prompt --application/set_environment
set define off verify off feedback off
whenever sqlerror exit sql.sqlcode rollback
--------------------------------------------------------------------------------
--
-- ORACLE Application Express (APEX) export file
--
-- You should run the script connected to SQL*Plus as the Oracle user
-- APEX_050100 or as the owner (parsing schema) of the application.
--
-- NOTE: Calls to apex_application_install override the defaults below.
--
--------------------------------------------------------------------------------
begin
wwv_flow_api.import_begin (
 p_version_yyyy_mm_dd=>'2016.08.24'
,p_release=>'5.1.4.00.08'
,p_default_workspace_id=>1959532611173926
,p_default_application_id=>100
,p_default_owner=>''
);
end;
/
prompt --application/shared_components/plugins/region_type/ir_apex_kpi_gauge
begin
wwv_flow_api.create_plugin(
 p_id=>wwv_flow_api.id(27056297969156447474)
,p_plugin_type=>'REGION TYPE'
,p_name=>'IR.APEX_KPI_GAUGE'
,p_display_name=>'APEX KPI GAUGE'
,p_supported_ui_types=>'DESKTOP'
,p_plsql_code=>wwv_flow_string.join(wwv_flow_t_varchar2(
'/****************************************************************************************',
'',
' --  Plugin      : APEX_KPI_GAUGE',
' --  InternalName: IR.APEX_KPI_GAUGE',
' --  Author      : Morteza Mashhadi',
' --  Create Date : Friday - 2019 25 January',
' --  Version     : 1.0',
' --  Description : Key performance indicator gauge for Oracle APEX',
' --  Website     : www.mortezamashhadi.blogspot.com',
'',
' ****************************************************************************************/',
'',
'',
'FUNCTION kpi_gauge (',
'    P_REGION              IN APEX_PLUGIN.T_REGION,',
'    P_PLUGIN              IN APEX_PLUGIN.T_PLUGIN,',
'    P_IS_PRINTER_FRIENDLY IN BOOLEAN )',
'  RETURN APEX_PLUGIN.T_REGION_RENDER_RESULT',
'IS',
'',
'gaugeName varchar(20):=''kpiGauge''||p_region.attribute_01;',
'gaugePoint number:=0;',
'startPoint number:=0;',
'endPoint number:=100;',
'startYellow number:=20;',
'startGreen number:=80;',
'l_column_value apex_plugin_util.t_column_value_list;',
'',
'--attributes',
'angle number:=nvl(p_region.attribute_02,0.12);',
'lineWidth number:=nvl(p_region.attribute_03,0.18);',
'radiusScale number:=nvl(p_region.attribute_04,0.99);',
'pointerLength number:=nvl(p_region.attribute_05,0.45);',
'pointerStrokeWidth number:=nvl(p_region.attribute_06,0.05);',
'pointerColor varchar(20):=nvl(p_region.attribute_07,''#000000'');',
'',
'--renderTicks',
'divisions number:=nvl(p_region.attribute_08,5);',
'divWidth number:=nvl(p_region.attribute_09,1.1);',
'divLength number:=nvl(p_region.attribute_10,0.7);',
'divColor varchar(20):=nvl(p_region.attribute_11,''#333333'');',
'subDivisions number:=nvl(p_region.attribute_12,3);',
'subLength number:=nvl(p_region.attribute_13,0.5);',
'subWidth number:=nvl(p_region.attribute_14,0.6);',
'subColor varchar(20):=nvl(p_region.attribute_15,''#666666'');',
'',
'begin',
'',
'',
'    --add javascript files',
'    apex_javascript.add_library (',
'        p_name      => ''apex_kpi_gauge'',',
'        p_directory => p_plugin.file_prefix,',
'        p_version   => null );',
'',
'',
'    l_column_value := APEX_PLUGIN_UTIL.GET_DATA (',
'        p_sql_statement    => P_REGION.source ,',
'        p_min_columns      => 5,',
'        p_max_columns      => 5,',
'        p_component_name   => P_REGION.NAME,',
'        p_search_type      => NULL,',
'        p_search_column_no => NULL,',
'        p_search_string    => NULL,',
'        p_first_row        => NULL,',
'        p_max_rows         => 1);',
'',
'    --Get value and Label from Query',
'        gaugePoint := apex_escape.html(l_column_value(1)(1));',
'        startPoint := apex_escape.html(l_column_value(2)(1));',
'        endPoint := apex_escape.html(l_column_value(3)(1));',
'        startYellow := apex_escape.html(l_column_value(4)(1));',
'        startGreen := apex_escape.html(l_column_value(5)(1));',
'',
'    sys.htp.p(''',
'              <div style="width:100%; text-align:center">',
'                <canvas width=400 height=150 id="''||gaugeName||''" ></canvas>',
'                <div id="''||gaugeName||''-textfield" style="margin: 0px auto;',
'                text-align: center;',
'                font-size: 18px;',
'                font-weight: bold;"></div>',
'              </div>',
'    '');',
'',
'    apex_javascript.add_onload_code(',
'        gaugeName||'' = new Gauge(document.getElementById("''||gaugeName||''"));',
'        var opts = {',
'          angle: ''||angle||'',',
'          lineWidth: ''||lineWidth||'',',
'          radiusScale:''||radiusScale||'',',
'          pointer: {',
'            length: ''||pointerLength||'',',
'            strokeWidth: ''||pointerStrokeWidth||'',',
'            color: "''||pointerColor||''"',
'          },',
'',
'          renderTicks: {',
'              divisions: ''||divisions||'',',
'              divWidth: ''||divWidth||'',',
'              divLength: ''||divLength||'',',
'              divColor: "''||divColor||''",',
'              subDivisions: ''||subDivisions||'',',
'              subLength: ''||subLength||'',',
'              subWidth: ''||subWidth||'',',
'              subColor: "''||subColor||''"',
'            },',
'',
'          staticLabels: {',
'            font: "10px sans-serif",',
'            labels: [''||startPoint||'',''||startYellow||'', ''||startGreen||'',''||endPoint||''],',
'            fractionDigits: 0',
'          },',
'          staticZones: [',
'             {strokeStyle: "#F03E3E", min: ''||startPoint||'', max: ''||startYellow||''},',
'             {strokeStyle: "#FFDD00", min: ''||startYellow||'', max: ''||startGreen||''},',
'             {strokeStyle: "#30B32D", min: ''||startGreen||'', max: ''||endPoint||''}',
'          ],',
'          limitMax: false,',
'          limitMin: false,',
'          highDpiSupport: true',
'        };',
'        ''||gaugeName||''.setOptions(opts);',
'        ''||gaugeName||''.setTextField(document.getElementById("''||gaugeName||''-textfield"));',
'        ''||gaugeName||''.minValue = ''||startPoint||'';',
'        ''||gaugeName||''.maxValue = ''||endPoint||'';',
'        ''||gaugeName||''.set(''||gaugePoint||'');',
'',
'    '');',
'',
'return null;',
'',
'end;'))
,p_api_version=>2
,p_render_function=>'kpi_gauge'
,p_standard_attributes=>'SOURCE_SQL:ESCAPE_OUTPUT'
,p_substitute_attributes=>true
,p_subscribe_plugin_settings=>true
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<p>',
'	Version 1.0<br />',
'	Date 01/25/2019<br />',
'	Author: Morteza Mashhadi<br />',
'	plugin APEX_BI_KPI_GAUGE<br />',
'	&nbsp;</p>',
'<p>',
'	This plugin create a KPI gauge with data comes from a query.</p>'))
,p_version_identifier=>'1.0'
,p_about_url=>'mortezamashhadi.blogspot.com'
,p_files_version=>4
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27053494878809378690)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>1
,p_display_sequence=>10
,p_prompt=>'Gauge Name'
,p_attribute_type=>'TEXT'
,p_is_required=>false
,p_default_value=>'kpiGauge'
,p_display_length=>10
,p_max_length=>10
,p_is_translatable=>false
,p_examples=>'myGage01'
,p_help_text=>'If you have more than one gauge in your page, set different names.'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27053504474798136909)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>2
,p_display_sequence=>20
,p_prompt=>'Angle'
,p_attribute_type=>'NUMBER'
,p_is_required=>false
,p_default_value=>'0.12'
,p_display_length=>4
,p_max_length=>4
,p_is_translatable=>false
,p_help_text=>'This parameter change the gauge view.'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27053505428158507274)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>3
,p_display_sequence=>30
,p_prompt=>'Line Width'
,p_attribute_type=>'NUMBER'
,p_is_required=>false
,p_default_value=>'0.18'
,p_display_length=>4
,p_max_length=>4
,p_is_translatable=>false
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27053516766694932012)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>4
,p_display_sequence=>40
,p_prompt=>'Radius Scale'
,p_attribute_type=>'NUMBER'
,p_is_required=>false
,p_default_value=>'0.99'
,p_display_length=>4
,p_max_length=>4
,p_is_translatable=>false
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27053512397179838148)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>5
,p_display_sequence=>50
,p_prompt=>'Pointer Length'
,p_attribute_type=>'NUMBER'
,p_is_required=>false
,p_default_value=>'0.45'
,p_display_length=>4
,p_max_length=>4
,p_is_translatable=>false
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27053512974701841838)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>6
,p_display_sequence=>60
,p_prompt=>'Pointer Stroke Width'
,p_attribute_type=>'NUMBER'
,p_is_required=>false
,p_default_value=>'0.05'
,p_display_length=>4
,p_max_length=>4
,p_is_translatable=>false
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27053513578738847585)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>7
,p_display_sequence=>70
,p_prompt=>'Pointer Color'
,p_attribute_type=>'TEXT'
,p_is_required=>false
,p_default_value=>'#000000'
,p_display_length=>10
,p_max_length=>10
,p_is_translatable=>false
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27053518538476073832)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>8
,p_display_sequence=>80
,p_prompt=>'Ticks Divisions'
,p_attribute_type=>'NUMBER'
,p_is_required=>false
,p_default_value=>'5'
,p_display_length=>4
,p_max_length=>4
,p_is_translatable=>false
,p_help_text=>'This is the number of major divisions around your arc.'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27053519179882081424)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>9
,p_display_sequence=>90
,p_prompt=>'Ticks DivWidth'
,p_attribute_type=>'NUMBER'
,p_is_required=>false
,p_default_value=>'1.1'
,p_display_length=>4
,p_max_length=>4
,p_is_translatable=>false
,p_help_text=>'This is to set the width of the indicator.'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27053519753958085874)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>10
,p_display_sequence=>100
,p_prompt=>'Ticks DivLength'
,p_attribute_type=>'NUMBER'
,p_is_required=>false
,p_default_value=>'0.7'
,p_display_length=>4
,p_max_length=>4
,p_is_translatable=>false
,p_help_text=>'This is a fractional percentage of the height of your arc line (0.5 = 50%).'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27053520396291091940)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>11
,p_display_sequence=>110
,p_prompt=>'Ticks DivColor'
,p_attribute_type=>'TEXT'
,p_is_required=>false
,p_default_value=>'#333333'
,p_display_length=>10
,p_max_length=>10
,p_is_translatable=>false
,p_help_text=>'This sets the color of the division markers.'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27053520950518095084)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>12
,p_display_sequence=>120
,p_prompt=>'Ticks SubDivisions'
,p_attribute_type=>'NUMBER'
,p_is_required=>false
,p_default_value=>'3'
,p_display_length=>4
,p_max_length=>4
,p_is_translatable=>false
,p_help_text=>'This sets the minor tick marks count between major ticks.'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27053521575268097946)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>13
,p_display_sequence=>130
,p_prompt=>'Ticks SubLength'
,p_attribute_type=>'NUMBER'
,p_is_required=>false
,p_default_value=>'0.5'
,p_display_length=>4
,p_max_length=>4
,p_is_translatable=>false
,p_help_text=>'This is a fractional percentage of the height of your arc line (0.5 = 50%).'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27053522179819099707)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>14
,p_display_sequence=>140
,p_prompt=>'Ticks SubWidth'
,p_attribute_type=>'NUMBER'
,p_is_required=>false
,p_default_value=>'0.6'
,p_display_length=>4
,p_max_length=>4
,p_is_translatable=>false
,p_help_text=>'This is to set the width of the indicator.'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(27053522743778103104)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>15
,p_display_sequence=>150
,p_prompt=>'Ticks SubColor'
,p_attribute_type=>'TEXT'
,p_is_required=>false
,p_default_value=>'#666666'
,p_display_length=>10
,p_max_length=>10
,p_is_translatable=>false
,p_help_text=>'This sets the color of the subdivision markers'
);
wwv_flow_api.create_plugin_std_attribute(
 p_id=>wwv_flow_api.id(27053490599716061596)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_name=>'SOURCE_SQL'
,p_default_value=>'select 50,0,100,20,80 from dual;'
,p_sql_min_column_count=>5
,p_sql_max_column_count=>5
,p_depending_on_has_to_exist=>true
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'This query must have this parameters: gaugePoint,startPoint,endPoint,startYellow,startGreen <br>',
'for example:<br>',
'<i>select 50,0,100,20,80 from dual;<br></i>',
'gauge point at 50<br>',
'start gauge at 0<br>',
'end gauge at 100<br>',
'start yellow color of gauge at 20<br>',
'and start green color of gauge at 80<br>'))
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '2F2F2047656E65726174656420627920436F6666656553637269707420312E31302E300A2866756E6374696F6E2829207B0A202076617220416E696D61746564546578742C20416E696D6174656454657874466163746F72792C204261722C2042617365';
wwv_flow_api.g_varchar2_table(2) := '446F6E75742C204261736547617567652C20446F6E75742C2047617567652C204761756765506F696E7465722C205465787452656E64657265722C2056616C7565557064617465722C20616464436F6D6D61732C206375744865782C20666F726D61744E';
wwv_flow_api.g_varchar2_table(3) := '756D6265722C206D657267654F626A656374732C207365636F6E6473546F537472696E672C0A20202020736C696365203D205B5D2E736C6963652C0A2020202068617350726F70203D207B7D2E6861734F776E50726F70657274792C0A20202020657874';
wwv_flow_api.g_varchar2_table(4) := '656E64203D2066756E6374696F6E286368696C642C20706172656E7429207B20666F722028766172206B657920696E20706172656E7429207B206966202868617350726F702E63616C6C28706172656E742C206B65792929206368696C645B6B65795D20';
wwv_flow_api.g_varchar2_table(5) := '3D20706172656E745B6B65795D3B207D2066756E6374696F6E2063746F722829207B20746869732E636F6E7374727563746F72203D206368696C643B207D2063746F722E70726F746F74797065203D20706172656E742E70726F746F747970653B206368';
wwv_flow_api.g_varchar2_table(6) := '696C642E70726F746F74797065203D206E65772063746F7228293B206368696C642E5F5F73757065725F5F203D20706172656E742E70726F746F747970653B2072657475726E206368696C643B207D3B0A0A20202866756E6374696F6E2829207B0A2020';
wwv_flow_api.g_varchar2_table(7) := '20207661722062726F7773657252657175657374416E696D6174696F6E4672616D652C20697343616E63656C6C65642C206A2C206C61737449642C206C656E2C2076656E646F722C2076656E646F72733B0A2020202076656E646F7273203D205B276D73';
wwv_flow_api.g_varchar2_table(8) := '272C20276D6F7A272C20277765626B6974272C20276F275D3B0A20202020666F7220286A203D20302C206C656E203D2076656E646F72732E6C656E6774683B206A203C206C656E3B206A2B2B29207B0A20202020202076656E646F72203D2076656E646F';
wwv_flow_api.g_varchar2_table(9) := '72735B6A5D3B0A2020202020206966202877696E646F772E72657175657374416E696D6174696F6E4672616D6529207B0A2020202020202020627265616B3B0A2020202020207D0A20202020202077696E646F772E72657175657374416E696D6174696F';
wwv_flow_api.g_varchar2_table(10) := '6E4672616D65203D2077696E646F775B76656E646F72202B202752657175657374416E696D6174696F6E4672616D65275D3B0A20202020202077696E646F772E63616E63656C416E696D6174696F6E4672616D65203D2077696E646F775B76656E646F72';
wwv_flow_api.g_varchar2_table(11) := '202B202743616E63656C416E696D6174696F6E4672616D65275D207C7C2077696E646F775B76656E646F72202B202743616E63656C52657175657374416E696D6174696F6E4672616D65275D3B0A202020207D0A2020202062726F777365725265717565';
wwv_flow_api.g_varchar2_table(12) := '7374416E696D6174696F6E4672616D65203D206E756C6C3B0A202020206C6173744964203D20303B0A20202020697343616E63656C6C6564203D207B7D3B0A20202020696620282172657175657374416E696D6174696F6E4672616D6529207B0A202020';
wwv_flow_api.g_varchar2_table(13) := '20202077696E646F772E72657175657374416E696D6174696F6E4672616D65203D2066756E6374696F6E2863616C6C6261636B2C20656C656D656E7429207B0A2020202020202020766172206375727254696D652C2069642C206C61737454696D652C20';
wwv_flow_api.g_varchar2_table(14) := '74696D65546F43616C6C3B0A20202020202020206375727254696D65203D206E6577204461746528292E67657454696D6528293B0A202020202020202074696D65546F43616C6C203D204D6174682E6D617828302C203136202D20286375727254696D65';
wwv_flow_api.g_varchar2_table(15) := '202D206C61737454696D6529293B0A20202020202020206964203D2077696E646F772E73657454696D656F75742866756E6374696F6E2829207B0A2020202020202020202072657475726E2063616C6C6261636B286375727254696D65202B2074696D65';
wwv_flow_api.g_varchar2_table(16) := '546F43616C6C293B0A20202020202020207D2C2074696D65546F43616C6C293B0A20202020202020206C61737454696D65203D206375727254696D65202B2074696D65546F43616C6C3B0A202020202020202072657475726E2069643B0A202020202020';
wwv_flow_api.g_varchar2_table(17) := '7D3B0A20202020202072657475726E2077696E646F772E63616E63656C416E696D6174696F6E4672616D65203D2066756E6374696F6E28696429207B0A202020202020202072657475726E20636C65617254696D656F7574286964293B0A202020202020';
wwv_flow_api.g_varchar2_table(18) := '7D3B0A202020207D20656C736520696620282177696E646F772E63616E63656C416E696D6174696F6E4672616D6529207B0A20202020202062726F7773657252657175657374416E696D6174696F6E4672616D65203D2077696E646F772E726571756573';
wwv_flow_api.g_varchar2_table(19) := '74416E696D6174696F6E4672616D653B0A20202020202077696E646F772E72657175657374416E696D6174696F6E4672616D65203D2066756E6374696F6E2863616C6C6261636B2C20656C656D656E7429207B0A2020202020202020766172206D794964';
wwv_flow_api.g_varchar2_table(20) := '3B0A20202020202020206D794964203D202B2B6C61737449643B0A202020202020202062726F7773657252657175657374416E696D6174696F6E4672616D652866756E6374696F6E2829207B0A202020202020202020206966202821697343616E63656C';
wwv_flow_api.g_varchar2_table(21) := '6C65645B6D7949645D29207B0A20202020202020202020202072657475726E2063616C6C6261636B28293B0A202020202020202020207D0A20202020202020207D2C20656C656D656E74293B0A202020202020202072657475726E206D7949643B0A2020';
wwv_flow_api.g_varchar2_table(22) := '202020207D3B0A20202020202072657475726E2077696E646F772E63616E63656C416E696D6174696F6E4672616D65203D2066756E6374696F6E28696429207B0A202020202020202072657475726E20697343616E63656C6C65645B69645D203D207472';
wwv_flow_api.g_varchar2_table(23) := '75653B0A2020202020207D3B0A202020207D0A20207D2928293B0A0A20207365636F6E6473546F537472696E67203D2066756E6374696F6E2873656329207B0A202020207661722068722C206D696E3B0A202020206872203D204D6174682E666C6F6F72';
wwv_flow_api.g_varchar2_table(24) := '28736563202F2033363030293B0A202020206D696E203D204D6174682E666C6F6F722828736563202D20286872202A20333630302929202F203630293B0A20202020736563202D3D20286872202A203336303029202B20286D696E202A203630293B0A20';
wwv_flow_api.g_varchar2_table(25) := '202020736563202B3D2027273B0A202020206D696E202B3D2027273B0A202020207768696C6520286D696E2E6C656E677468203C203229207B0A2020202020206D696E203D20273027202B206D696E3B0A202020207D0A202020207768696C6520287365';
wwv_flow_api.g_varchar2_table(26) := '632E6C656E677468203C203229207B0A202020202020736563203D20273027202B207365633B0A202020207D0A202020206872203D206872203F206872202B20273A27203A2027273B0A2020202072657475726E206872202B206D696E202B20273A2720';
wwv_flow_api.g_varchar2_table(27) := '2B207365633B0A20207D3B0A0A2020666F726D61744E756D626572203D2066756E6374696F6E2829207B0A20202020766172206469676974732C206E756D2C2076616C75653B0A202020206E756D203D2031203C3D20617267756D656E74732E6C656E67';
wwv_flow_api.g_varchar2_table(28) := '7468203F20736C6963652E63616C6C28617267756D656E74732C203029203A205B5D3B0A2020202076616C7565203D206E756D5B305D3B0A20202020646967697473203D2030207C7C206E756D5B315D3B0A2020202072657475726E20616464436F6D6D';
wwv_flow_api.g_varchar2_table(29) := '61732876616C75652E746F46697865642864696769747329293B0A20207D3B0A0A20206D657267654F626A65637473203D2066756E6374696F6E286F626A312C206F626A3229207B0A20202020766172206B65792C206F75742C2076616C3B0A20202020';
wwv_flow_api.g_varchar2_table(30) := '6F7574203D207B7D3B0A20202020666F7220286B657920696E206F626A3129207B0A202020202020696620282168617350726F702E63616C6C286F626A312C206B6579292920636F6E74696E75653B0A20202020202076616C203D206F626A315B6B6579';
wwv_flow_api.g_varchar2_table(31) := '5D3B0A2020202020206F75745B6B65795D203D2076616C3B0A202020207D0A20202020666F7220286B657920696E206F626A3229207B0A202020202020696620282168617350726F702E63616C6C286F626A322C206B6579292920636F6E74696E75653B';
wwv_flow_api.g_varchar2_table(32) := '0A20202020202076616C203D206F626A325B6B65795D3B0A2020202020206F75745B6B65795D203D2076616C3B0A202020207D0A2020202072657475726E206F75743B0A20207D3B0A0A2020616464436F6D6D6173203D2066756E6374696F6E286E5374';
wwv_flow_api.g_varchar2_table(33) := '7229207B0A20202020766172207267782C20782C2078312C2078323B0A202020206E537472202B3D2027273B0A2020202078203D206E5374722E73706C697428272E27293B0A202020207831203D20785B305D3B0A202020207832203D2027273B0A2020';
wwv_flow_api.g_varchar2_table(34) := '202069662028782E6C656E677468203E203129207B0A2020202020207832203D20272E27202B20785B315D3B0A202020207D0A20202020726778203D202F285C642B29285C647B337D292F3B0A202020207768696C6520287267782E7465737428783129';
wwv_flow_api.g_varchar2_table(35) := '29207B0A2020202020207831203D2078312E7265706C616365287267782C2027243127202B20272C27202B2027243227293B0A202020207D0A2020202072657475726E207831202B2078323B0A20207D3B0A0A2020637574486578203D2066756E637469';
wwv_flow_api.g_varchar2_table(36) := '6F6E286E53747229207B0A20202020696620286E5374722E636861724174283029203D3D3D2022232229207B0A20202020202072657475726E206E5374722E737562737472696E6728312C2037293B0A202020207D0A2020202072657475726E206E5374';
wwv_flow_api.g_varchar2_table(37) := '723B0A20207D3B0A0A202056616C756555706461746572203D202866756E6374696F6E2829207B0A2020202056616C7565557064617465722E70726F746F747970652E616E696D6174696F6E5370656564203D2033323B0A0A2020202066756E6374696F';
wwv_flow_api.g_varchar2_table(38) := '6E2056616C75655570646174657228616464546F416E696D6174696F6E51756575652C20636C65617229207B0A20202020202069662028616464546F416E696D6174696F6E5175657565203D3D206E756C6C29207B0A2020202020202020616464546F41';
wwv_flow_api.g_varchar2_table(39) := '6E696D6174696F6E5175657565203D20747275653B0A2020202020207D0A202020202020746869732E636C656172203D20636C65617220213D206E756C6C203F20636C656172203A20747275653B0A20202020202069662028616464546F416E696D6174';
wwv_flow_api.g_varchar2_table(40) := '696F6E517565756529207B0A2020202020202020416E696D6174696F6E557064617465722E6164642874686973293B0A2020202020207D0A202020207D0A0A2020202056616C7565557064617465722E70726F746F747970652E757064617465203D2066';
wwv_flow_api.g_varchar2_table(41) := '756E6374696F6E28666F72636529207B0A20202020202076617220646966663B0A20202020202069662028666F726365203D3D206E756C6C29207B0A2020202020202020666F726365203D2066616C73653B0A2020202020207D0A202020202020696620';
wwv_flow_api.g_varchar2_table(42) := '28666F726365207C7C20746869732E646973706C6179656456616C756520213D3D20746869732E76616C756529207B0A202020202020202069662028746869732E63747820262620746869732E636C65617229207B0A2020202020202020202074686973';
wwv_flow_api.g_varchar2_table(43) := '2E6374782E636C6561725265637428302C20302C20746869732E63616E7661732E77696474682C20746869732E63616E7661732E686569676874293B0A20202020202020207D0A202020202020202064696666203D20746869732E76616C7565202D2074';
wwv_flow_api.g_varchar2_table(44) := '6869732E646973706C6179656456616C75653B0A2020202020202020696620284D6174682E6162732864696666202F20746869732E616E696D6174696F6E537065656429203C3D20302E30303129207B0A20202020202020202020746869732E64697370';
wwv_flow_api.g_varchar2_table(45) := '6C6179656456616C7565203D20746869732E76616C75653B0A20202020202020207D20656C7365207B0A20202020202020202020746869732E646973706C6179656456616C7565203D20746869732E646973706C6179656456616C7565202B2064696666';
wwv_flow_api.g_varchar2_table(46) := '202F20746869732E616E696D6174696F6E53706565643B0A20202020202020207D0A2020202020202020746869732E72656E64657228293B0A202020202020202072657475726E20747275653B0A2020202020207D0A20202020202072657475726E2066';
wwv_flow_api.g_varchar2_table(47) := '616C73653B0A202020207D3B0A0A2020202072657475726E2056616C7565557064617465723B0A0A20207D2928293B0A0A2020426173654761756765203D202866756E6374696F6E287375706572436C61737329207B0A20202020657874656E64284261';
wwv_flow_api.g_varchar2_table(48) := '736547617567652C207375706572436C617373293B0A0A2020202066756E6374696F6E204261736547617567652829207B0A20202020202072657475726E204261736547617567652E5F5F73757065725F5F2E636F6E7374727563746F722E6170706C79';
wwv_flow_api.g_varchar2_table(49) := '28746869732C20617267756D656E7473293B0A202020207D0A0A202020204261736547617567652E70726F746F747970652E646973706C61795363616C65203D20313B0A0A202020204261736547617567652E70726F746F747970652E666F7263655570';
wwv_flow_api.g_varchar2_table(50) := '64617465203D20747275653B0A0A202020204261736547617567652E70726F746F747970652E736574546578744669656C64203D2066756E6374696F6E28746578744669656C642C206672616374696F6E44696769747329207B0A202020202020726574';
wwv_flow_api.g_varchar2_table(51) := '75726E20746869732E746578744669656C64203D20746578744669656C6420696E7374616E63656F66205465787452656E6465726572203F20746578744669656C64203A206E6577205465787452656E646572657228746578744669656C642C20667261';
wwv_flow_api.g_varchar2_table(52) := '6374696F6E446967697473293B0A202020207D3B0A0A202020204261736547617567652E70726F746F747970652E7365744D696E56616C7565203D2066756E6374696F6E286D696E56616C75652C20757064617465537461727456616C756529207B0A20';
wwv_flow_api.g_varchar2_table(53) := '20202020207661722067617567652C206A2C206C656E2C207265662C20726573756C74733B0A202020202020746869732E6D696E56616C7565203D206D696E56616C75653B0A20202020202069662028757064617465537461727456616C7565203D3D20';
wwv_flow_api.g_varchar2_table(54) := '6E756C6C29207B0A2020202020202020757064617465537461727456616C7565203D20747275653B0A2020202020207D0A20202020202069662028757064617465537461727456616C756529207B0A2020202020202020746869732E646973706C617965';
wwv_flow_api.g_varchar2_table(55) := '6456616C7565203D20746869732E6D696E56616C75653B0A2020202020202020726566203D20746869732E6770207C7C205B5D3B0A2020202020202020726573756C7473203D205B5D3B0A2020202020202020666F7220286A203D20302C206C656E203D';
wwv_flow_api.g_varchar2_table(56) := '207265662E6C656E6774683B206A203C206C656E3B206A2B2B29207B0A202020202020202020206761756765203D207265665B6A5D3B0A20202020202020202020726573756C74732E707573682867617567652E646973706C6179656456616C7565203D';
wwv_flow_api.g_varchar2_table(57) := '20746869732E6D696E56616C7565293B0A20202020202020207D0A202020202020202072657475726E20726573756C74733B0A2020202020207D0A202020207D3B0A0A202020204261736547617567652E70726F746F747970652E7365744F7074696F6E';
wwv_flow_api.g_varchar2_table(58) := '73203D2066756E6374696F6E286F7074696F6E7329207B0A202020202020696620286F7074696F6E73203D3D206E756C6C29207B0A20202020202020206F7074696F6E73203D206E756C6C3B0A2020202020207D0A202020202020746869732E6F707469';
wwv_flow_api.g_varchar2_table(59) := '6F6E73203D206D657267654F626A6563747328746869732E6F7074696F6E732C206F7074696F6E73293B0A20202020202069662028746869732E746578744669656C6429207B0A2020202020202020746869732E746578744669656C642E656C2E737479';
wwv_flow_api.g_varchar2_table(60) := '6C652E666F6E7453697A65203D206F7074696F6E732E666F6E7453697A65202B20277078273B0A2020202020207D0A20202020202069662028746869732E6F7074696F6E732E616E676C65203E202E3529207B0A2020202020202020746869732E6F7074';
wwv_flow_api.g_varchar2_table(61) := '696F6E732E616E676C65203D202E353B0A2020202020207D0A202020202020746869732E636F6E666967446973706C61795363616C6528293B0A20202020202072657475726E20746869733B0A202020207D3B0A0A202020204261736547617567652E70';
wwv_flow_api.g_varchar2_table(62) := '726F746F747970652E636F6E666967446973706C61795363616C65203D2066756E6374696F6E2829207B0A202020202020766172206261636B696E6753746F7265506978656C526174696F2C20646576696365506978656C526174696F2C206865696768';
wwv_flow_api.g_varchar2_table(63) := '742C2070726576446973706C61795363616C652C2077696474683B0A20202020202070726576446973706C61795363616C65203D20746869732E646973706C61795363616C653B0A20202020202069662028746869732E6F7074696F6E732E6869676844';
wwv_flow_api.g_varchar2_table(64) := '7069537570706F7274203D3D3D2066616C736529207B0A202020202020202064656C65746520746869732E646973706C61795363616C653B0A2020202020207D20656C7365207B0A2020202020202020646576696365506978656C526174696F203D2077';
wwv_flow_api.g_varchar2_table(65) := '696E646F772E646576696365506978656C526174696F207C7C20313B0A20202020202020206261636B696E6753746F7265506978656C526174696F203D20746869732E6374782E7765626B69744261636B696E6753746F7265506978656C526174696F20';
wwv_flow_api.g_varchar2_table(66) := '7C7C20746869732E6374782E6D6F7A4261636B696E6753746F7265506978656C526174696F207C7C20746869732E6374782E6D734261636B696E6753746F7265506978656C526174696F207C7C20746869732E6374782E6F4261636B696E6753746F7265';
wwv_flow_api.g_varchar2_table(67) := '506978656C526174696F207C7C20746869732E6374782E6261636B696E6753746F7265506978656C526174696F207C7C20313B0A2020202020202020746869732E646973706C61795363616C65203D20646576696365506978656C526174696F202F2062';
wwv_flow_api.g_varchar2_table(68) := '61636B696E6753746F7265506978656C526174696F3B0A2020202020207D0A20202020202069662028746869732E646973706C61795363616C6520213D3D2070726576446973706C61795363616C6529207B0A20202020202020207769647468203D2074';
wwv_flow_api.g_varchar2_table(69) := '6869732E63616E7661732E475F5F7769647468207C7C20746869732E63616E7661732E77696474683B0A2020202020202020686569676874203D20746869732E63616E7661732E475F5F686569676874207C7C20746869732E63616E7661732E68656967';
wwv_flow_api.g_varchar2_table(70) := '68743B0A2020202020202020746869732E63616E7661732E7769647468203D207769647468202A20746869732E646973706C61795363616C653B0A2020202020202020746869732E63616E7661732E686569676874203D20686569676874202A20746869';
wwv_flow_api.g_varchar2_table(71) := '732E646973706C61795363616C653B0A2020202020202020746869732E63616E7661732E7374796C652E7769647468203D207769647468202B20227078223B0A2020202020202020746869732E63616E7661732E7374796C652E686569676874203D2068';
wwv_flow_api.g_varchar2_table(72) := '6569676874202B20227078223B0A2020202020202020746869732E63616E7661732E475F5F7769647468203D2077696474683B0A2020202020202020746869732E63616E7661732E475F5F686569676874203D206865696768743B0A2020202020207D0A';
wwv_flow_api.g_varchar2_table(73) := '20202020202072657475726E20746869733B0A202020207D3B0A0A202020204261736547617567652E70726F746F747970652E706172736556616C7565203D2066756E6374696F6E2876616C756529207B0A20202020202076616C7565203D2070617273';
wwv_flow_api.g_varchar2_table(74) := '65466C6F61742876616C756529207C7C204E756D6265722876616C7565293B0A20202020202069662028697346696E6974652876616C75652929207B0A202020202020202072657475726E2076616C75653B0A2020202020207D20656C7365207B0A2020';
wwv_flow_api.g_varchar2_table(75) := '20202020202072657475726E20303B0A2020202020207D0A202020207D3B0A0A2020202072657475726E204261736547617567653B0A0A20207D292856616C756555706461746572293B0A0A20205465787452656E6465726572203D202866756E637469';
wwv_flow_api.g_varchar2_table(76) := '6F6E2829207B0A2020202066756E6374696F6E205465787452656E646572657228656C2C206672616374696F6E4469676974733129207B0A202020202020746869732E656C203D20656C3B0A202020202020746869732E6672616374696F6E4469676974';
wwv_flow_api.g_varchar2_table(77) := '73203D206672616374696F6E446967697473313B0A202020207D0A0A202020205465787452656E64657265722E70726F746F747970652E72656E646572203D2066756E6374696F6E28676175676529207B0A20202020202072657475726E20746869732E';
wwv_flow_api.g_varchar2_table(78) := '656C2E696E6E657248544D4C203D20666F726D61744E756D6265722867617567652E646973706C6179656456616C75652C20746869732E6672616374696F6E446967697473293B0A202020207D3B0A0A2020202072657475726E205465787452656E6465';
wwv_flow_api.g_varchar2_table(79) := '7265723B0A0A20207D2928293B0A0A2020416E696D6174656454657874203D202866756E6374696F6E287375706572436C61737329207B0A20202020657874656E6428416E696D61746564546578742C207375706572436C617373293B0A0A2020202041';
wwv_flow_api.g_varchar2_table(80) := '6E696D61746564546578742E70726F746F747970652E646973706C6179656456616C7565203D20303B0A0A20202020416E696D61746564546578742E70726F746F747970652E76616C7565203D20303B0A0A20202020416E696D61746564546578742E70';
wwv_flow_api.g_varchar2_table(81) := '726F746F747970652E73657456616C203D2066756E6374696F6E2876616C756529207B0A20202020202072657475726E20746869732E76616C7565203D2031202A2076616C75653B0A202020207D3B0A0A2020202066756E6374696F6E20416E696D6174';
wwv_flow_api.g_varchar2_table(82) := '65645465787428656C656D312C207465787429207B0A202020202020746869732E656C656D203D20656C656D313B0A202020202020746869732E74657874203D207465787420213D206E756C6C203F2074657874203A2066616C73653B0A202020202020';
wwv_flow_api.g_varchar2_table(83) := '416E696D61746564546578742E5F5F73757065725F5F2E636F6E7374727563746F722E63616C6C2874686973293B0A20202020202069662028746869732E656C656D203D3D3D20766F6964203029207B0A20202020202020207468726F77206E65772045';
wwv_flow_api.g_varchar2_table(84) := '72726F72282754686520656C656D656E742069736E5C277420646566696E65642E27293B0A2020202020207D0A202020202020746869732E76616C7565203D2031202A20746869732E656C656D2E696E6E657248544D4C3B0A2020202020206966202874';
wwv_flow_api.g_varchar2_table(85) := '6869732E7465787429207B0A2020202020202020746869732E76616C7565203D20303B0A2020202020207D0A202020207D0A0A20202020416E696D61746564546578742E70726F746F747970652E72656E646572203D2066756E6374696F6E2829207B0A';
wwv_flow_api.g_varchar2_table(86) := '202020202020766172207465787456616C3B0A20202020202069662028746869732E7465787429207B0A20202020202020207465787456616C203D207365636F6E6473546F537472696E6728746869732E646973706C6179656456616C75652E746F4669';
wwv_flow_api.g_varchar2_table(87) := '786564283029293B0A2020202020207D20656C7365207B0A20202020202020207465787456616C203D20616464436F6D6D617328666F726D61744E756D62657228746869732E646973706C6179656456616C756529293B0A2020202020207D0A20202020';
wwv_flow_api.g_varchar2_table(88) := '202072657475726E20746869732E656C656D2E696E6E657248544D4C203D207465787456616C3B0A202020207D3B0A0A2020202072657475726E20416E696D61746564546578743B0A0A20207D292856616C756555706461746572293B0A0A2020416E69';
wwv_flow_api.g_varchar2_table(89) := '6D6174656454657874466163746F7279203D207B0A202020206372656174653A2066756E6374696F6E286F626A4C69737429207B0A20202020202076617220656C656D2C206A2C206C656E2C206F75743B0A2020202020206F7574203D205B5D3B0A2020';
wwv_flow_api.g_varchar2_table(90) := '20202020666F7220286A203D20302C206C656E203D206F626A4C6973742E6C656E6774683B206A203C206C656E3B206A2B2B29207B0A2020202020202020656C656D203D206F626A4C6973745B6A5D3B0A20202020202020206F75742E70757368286E65';
wwv_flow_api.g_varchar2_table(91) := '7720416E696D617465645465787428656C656D29293B0A2020202020207D0A20202020202072657475726E206F75743B0A202020207D0A20207D3B0A0A20204761756765506F696E746572203D202866756E6374696F6E287375706572436C6173732920';
wwv_flow_api.g_varchar2_table(92) := '7B0A20202020657874656E64284761756765506F696E7465722C207375706572436C617373293B0A0A202020204761756765506F696E7465722E70726F746F747970652E646973706C6179656456616C7565203D20303B0A0A202020204761756765506F';
wwv_flow_api.g_varchar2_table(93) := '696E7465722E70726F746F747970652E76616C7565203D20303B0A0A202020204761756765506F696E7465722E70726F746F747970652E6F7074696F6E73203D207B0A2020202020207374726F6B6557696474683A20302E3033352C0A2020202020206C';
wwv_flow_api.g_varchar2_table(94) := '656E6774683A20302E312C0A202020202020636F6C6F723A202223303030303030222C0A20202020202069636F6E506174683A206E756C6C2C0A20202020202069636F6E5363616C653A20312E302C0A20202020202069636F6E416E676C653A20300A20';
wwv_flow_api.g_varchar2_table(95) := '2020207D3B0A0A202020204761756765506F696E7465722E70726F746F747970652E696D67203D206E756C6C3B0A0A2020202066756E6374696F6E204761756765506F696E7465722867617567653129207B0A202020202020746869732E676175676520';
wwv_flow_api.g_varchar2_table(96) := '3D206761756765313B0A20202020202069662028746869732E6761756765203D3D3D20766F6964203029207B0A20202020202020207468726F77206E6577204572726F72282754686520656C656D656E742069736E5C277420646566696E65642E27293B';
wwv_flow_api.g_varchar2_table(97) := '0A2020202020207D0A202020202020746869732E637478203D20746869732E67617567652E6374783B0A202020202020746869732E63616E766173203D20746869732E67617567652E63616E7661733B0A2020202020204761756765506F696E7465722E';
wwv_flow_api.g_varchar2_table(98) := '5F5F73757065725F5F2E636F6E7374727563746F722E63616C6C28746869732C2066616C73652C2066616C7365293B0A202020202020746869732E7365744F7074696F6E7328293B0A202020207D0A0A202020204761756765506F696E7465722E70726F';
wwv_flow_api.g_varchar2_table(99) := '746F747970652E7365744F7074696F6E73203D2066756E6374696F6E286F7074696F6E7329207B0A202020202020696620286F7074696F6E73203D3D206E756C6C29207B0A20202020202020206F7074696F6E73203D206E756C6C3B0A2020202020207D';
wwv_flow_api.g_varchar2_table(100) := '0A202020202020746869732E6F7074696F6E73203D206D657267654F626A6563747328746869732E6F7074696F6E732C206F7074696F6E73293B0A202020202020746869732E6C656E677468203D2032202A20746869732E67617567652E726164697573';
wwv_flow_api.g_varchar2_table(101) := '202A20746869732E67617567652E6F7074696F6E732E7261646975735363616C65202A20746869732E6F7074696F6E732E6C656E6774683B0A202020202020746869732E7374726F6B655769647468203D20746869732E63616E7661732E686569676874';
wwv_flow_api.g_varchar2_table(102) := '202A20746869732E6F7074696F6E732E7374726F6B6557696474683B0A202020202020746869732E6D617856616C7565203D20746869732E67617567652E6D617856616C75653B0A202020202020746869732E6D696E56616C7565203D20746869732E67';
wwv_flow_api.g_varchar2_table(103) := '617567652E6D696E56616C75653B0A202020202020746869732E616E696D6174696F6E5370656564203D20746869732E67617567652E616E696D6174696F6E53706565643B0A202020202020746869732E6F7074696F6E732E616E676C65203D20746869';
wwv_flow_api.g_varchar2_table(104) := '732E67617567652E6F7074696F6E732E616E676C653B0A20202020202069662028746869732E6F7074696F6E732E69636F6E5061746829207B0A2020202020202020746869732E696D67203D206E657720496D61676528293B0A20202020202020207265';
wwv_flow_api.g_varchar2_table(105) := '7475726E20746869732E696D672E737263203D20746869732E6F7074696F6E732E69636F6E506174683B0A2020202020207D0A202020207D3B0A0A202020204761756765506F696E7465722E70726F746F747970652E72656E646572203D2066756E6374';
wwv_flow_api.g_varchar2_table(106) := '696F6E2829207B0A20202020202076617220616E676C652C20656E64582C20656E64592C20696D67582C20696D67592C207374617274582C207374617274592C20782C20793B0A202020202020616E676C65203D20746869732E67617567652E67657441';
wwv_flow_api.g_varchar2_table(107) := '6E676C652E63616C6C28746869732C20746869732E646973706C6179656456616C7565293B0A20202020202078203D204D6174682E726F756E6428746869732E6C656E677468202A204D6174682E636F7328616E676C6529293B0A20202020202079203D';
wwv_flow_api.g_varchar2_table(108) := '204D6174682E726F756E6428746869732E6C656E677468202A204D6174682E73696E28616E676C6529293B0A202020202020737461727458203D204D6174682E726F756E6428746869732E7374726F6B655769647468202A204D6174682E636F7328616E';
wwv_flow_api.g_varchar2_table(109) := '676C65202D204D6174682E5049202F203229293B0A202020202020737461727459203D204D6174682E726F756E6428746869732E7374726F6B655769647468202A204D6174682E73696E28616E676C65202D204D6174682E5049202F203229293B0A2020';
wwv_flow_api.g_varchar2_table(110) := '20202020656E6458203D204D6174682E726F756E6428746869732E7374726F6B655769647468202A204D6174682E636F7328616E676C65202B204D6174682E5049202F203229293B0A202020202020656E6459203D204D6174682E726F756E6428746869';
wwv_flow_api.g_varchar2_table(111) := '732E7374726F6B655769647468202A204D6174682E73696E28616E676C65202B204D6174682E5049202F203229293B0A202020202020746869732E6374782E626567696E5061746828293B0A202020202020746869732E6374782E66696C6C5374796C65';
wwv_flow_api.g_varchar2_table(112) := '203D20746869732E6F7074696F6E732E636F6C6F723B0A202020202020746869732E6374782E61726328302C20302C20746869732E7374726F6B6557696474682C20302C204D6174682E5049202A20322C2066616C7365293B0A20202020202074686973';
wwv_flow_api.g_varchar2_table(113) := '2E6374782E66696C6C28293B0A202020202020746869732E6374782E626567696E5061746828293B0A202020202020746869732E6374782E6D6F7665546F287374617274582C20737461727459293B0A202020202020746869732E6374782E6C696E6554';
wwv_flow_api.g_varchar2_table(114) := '6F28782C2079293B0A202020202020746869732E6374782E6C696E65546F28656E64582C20656E6459293B0A202020202020746869732E6374782E66696C6C28293B0A20202020202069662028746869732E696D6729207B0A2020202020202020696D67';
wwv_flow_api.g_varchar2_table(115) := '58203D204D6174682E726F756E6428746869732E696D672E7769647468202A20746869732E6F7074696F6E732E69636F6E5363616C65293B0A2020202020202020696D6759203D204D6174682E726F756E6428746869732E696D672E686569676874202A';
wwv_flow_api.g_varchar2_table(116) := '20746869732E6F7074696F6E732E69636F6E5363616C65293B0A2020202020202020746869732E6374782E7361766528293B0A2020202020202020746869732E6374782E7472616E736C61746528782C2079293B0A2020202020202020746869732E6374';
wwv_flow_api.g_varchar2_table(117) := '782E726F7461746528616E676C65202B204D6174682E5049202F203138302E30202A20283930202B20746869732E6F7074696F6E732E69636F6E416E676C6529293B0A2020202020202020746869732E6374782E64726177496D61676528746869732E69';
wwv_flow_api.g_varchar2_table(118) := '6D672C202D696D6758202F20322C202D696D6759202F20322C20696D67582C20696D6759293B0A202020202020202072657475726E20746869732E6374782E726573746F726528293B0A2020202020207D0A202020207D3B0A0A2020202072657475726E';
wwv_flow_api.g_varchar2_table(119) := '204761756765506F696E7465723B0A0A20207D292856616C756555706461746572293B0A0A2020426172203D202866756E6374696F6E2829207B0A2020202066756E6374696F6E2042617228656C656D3129207B0A202020202020746869732E656C656D';
wwv_flow_api.g_varchar2_table(120) := '203D20656C656D313B0A202020207D0A0A202020204261722E70726F746F747970652E75706461746556616C756573203D2066756E6374696F6E2861727256616C75657329207B0A202020202020746869732E76616C7565203D2061727256616C756573';
wwv_flow_api.g_varchar2_table(121) := '5B305D3B0A202020202020746869732E6D617856616C7565203D2061727256616C7565735B315D3B0A202020202020746869732E61766756616C7565203D2061727256616C7565735B325D3B0A20202020202072657475726E20746869732E72656E6465';
wwv_flow_api.g_varchar2_table(122) := '7228293B0A202020207D3B0A0A202020204261722E70726F746F747970652E72656E646572203D2066756E6374696F6E2829207B0A2020202020207661722061766750657263656E742C2076616C50657263656E743B0A20202020202069662028746869';
wwv_flow_api.g_varchar2_table(123) := '732E746578744669656C6429207B0A2020202020202020746869732E746578744669656C642E7465787428666F726D61744E756D62657228746869732E76616C756529293B0A2020202020207D0A20202020202069662028746869732E6D617856616C75';
wwv_flow_api.g_varchar2_table(124) := '65203D3D3D203029207B0A2020202020202020746869732E6D617856616C7565203D20746869732E61766756616C7565202A20323B0A2020202020207D0A20202020202076616C50657263656E74203D2028746869732E76616C7565202F20746869732E';
wwv_flow_api.g_varchar2_table(125) := '6D617856616C756529202A203130303B0A20202020202061766750657263656E74203D2028746869732E61766756616C7565202F20746869732E6D617856616C756529202A203130303B0A2020202020202428222E6261722D76616C7565222C20746869';
wwv_flow_api.g_varchar2_table(126) := '732E656C656D292E637373287B0A2020202020202020227769647468223A2076616C50657263656E74202B202225220A2020202020207D293B0A20202020202072657475726E202428222E7479706963616C2D76616C7565222C20746869732E656C656D';
wwv_flow_api.g_varchar2_table(127) := '292E637373287B0A2020202020202020227769647468223A2061766750657263656E74202B202225220A2020202020207D293B0A202020207D3B0A0A2020202072657475726E204261723B0A0A20207D2928293B0A0A20204761756765203D202866756E';
wwv_flow_api.g_varchar2_table(128) := '6374696F6E287375706572436C61737329207B0A20202020657874656E642847617567652C207375706572436C617373293B0A0A2020202047617567652E70726F746F747970652E656C656D203D206E756C6C3B0A0A2020202047617567652E70726F74';
wwv_flow_api.g_varchar2_table(129) := '6F747970652E76616C7565203D205B32305D3B0A0A2020202047617567652E70726F746F747970652E6D617856616C7565203D2038303B0A0A2020202047617567652E70726F746F747970652E6D696E56616C7565203D20303B0A0A2020202047617567';
wwv_flow_api.g_varchar2_table(130) := '652E70726F746F747970652E646973706C61796564416E676C65203D20303B0A0A2020202047617567652E70726F746F747970652E646973706C6179656456616C7565203D20303B0A0A2020202047617567652E70726F746F747970652E6C696E655769';
wwv_flow_api.g_varchar2_table(131) := '647468203D2034303B0A0A2020202047617567652E70726F746F747970652E70616464696E67546F70203D20302E313B0A0A2020202047617567652E70726F746F747970652E70616464696E67426F74746F6D203D20302E313B0A0A2020202047617567';
wwv_flow_api.g_varchar2_table(132) := '652E70726F746F747970652E70657263656E74436F6C6F7273203D206E756C6C3B0A0A2020202047617567652E70726F746F747970652E6F7074696F6E73203D207B0A202020202020636F6C6F7253746172743A202223366661646366222C0A20202020';
wwv_flow_api.g_varchar2_table(133) := '2020636F6C6F7253746F703A20766F696420302C0A2020202020206772616469656E74547970653A20302C0A2020202020207374726F6B65436F6C6F723A202223653065306530222C0A202020202020706F696E7465723A207B0A20202020202020206C';
wwv_flow_api.g_varchar2_table(134) := '656E6774683A20302E382C0A20202020202020207374726F6B6557696474683A20302E3033352C0A202020202020202069636F6E5363616C653A20312E300A2020202020207D2C0A202020202020616E676C653A20302E31352C0A2020202020206C696E';
wwv_flow_api.g_varchar2_table(135) := '6557696474683A20302E34342C0A2020202020207261646975735363616C653A20312E302C0A202020202020666F6E7453697A653A2034302C0A2020202020206C696D69744D61783A2066616C73652C0A2020202020206C696D69744D696E3A2066616C';
wwv_flow_api.g_varchar2_table(136) := '73650A202020207D3B0A0A2020202066756E6374696F6E2047617567652863616E76617329207B0A20202020202076617220682C20773B0A202020202020746869732E63616E766173203D2063616E7661733B0A20202020202047617567652E5F5F7375';
wwv_flow_api.g_varchar2_table(137) := '7065725F5F2E636F6E7374727563746F722E63616C6C2874686973293B0A202020202020746869732E70657263656E74436F6C6F7273203D206E756C6C3B0A20202020202069662028747970656F6620475F766D6C43616E7661734D616E616765722021';
wwv_flow_api.g_varchar2_table(138) := '3D3D2027756E646566696E65642729207B0A2020202020202020746869732E63616E766173203D2077696E646F772E475F766D6C43616E7661734D616E616765722E696E6974456C656D656E7428746869732E63616E766173293B0A2020202020207D0A';
wwv_flow_api.g_varchar2_table(139) := '202020202020746869732E637478203D20746869732E63616E7661732E676574436F6E746578742827326427293B0A20202020202068203D20746869732E63616E7661732E636C69656E744865696768743B0A20202020202077203D20746869732E6361';
wwv_flow_api.g_varchar2_table(140) := '6E7661732E636C69656E7457696474683B0A202020202020746869732E63616E7661732E686569676874203D20683B0A202020202020746869732E63616E7661732E7769647468203D20773B0A202020202020746869732E6770203D205B6E6577204761';
wwv_flow_api.g_varchar2_table(141) := '756765506F696E7465722874686973295D3B0A202020202020746869732E7365744F7074696F6E7328293B0A202020207D0A0A2020202047617567652E70726F746F747970652E7365744F7074696F6E73203D2066756E6374696F6E286F7074696F6E73';
wwv_flow_api.g_varchar2_table(142) := '29207B0A2020202020207661722067617567652C206A2C206C656E2C207068692C207265663B0A202020202020696620286F7074696F6E73203D3D206E756C6C29207B0A20202020202020206F7074696F6E73203D206E756C6C3B0A2020202020207D0A';
wwv_flow_api.g_varchar2_table(143) := '20202020202047617567652E5F5F73757065725F5F2E7365744F7074696F6E732E63616C6C28746869732C206F7074696F6E73293B0A202020202020746869732E636F6E66696750657263656E74436F6C6F727328293B0A202020202020746869732E65';
wwv_flow_api.g_varchar2_table(144) := '7874726150616464696E67203D20303B0A20202020202069662028746869732E6F7074696F6E732E616E676C65203C203029207B0A2020202020202020706869203D204D6174682E5049202A202831202B20746869732E6F7074696F6E732E616E676C65';
wwv_flow_api.g_varchar2_table(145) := '293B0A2020202020202020746869732E657874726150616464696E67203D204D6174682E73696E28706869293B0A2020202020207D0A202020202020746869732E617661696C61626C65486569676874203D20746869732E63616E7661732E6865696768';
wwv_flow_api.g_varchar2_table(146) := '74202A202831202D20746869732E70616464696E67546F70202D20746869732E70616464696E67426F74746F6D293B0A202020202020746869732E6C696E655769647468203D20746869732E617661696C61626C65486569676874202A20746869732E6F';
wwv_flow_api.g_varchar2_table(147) := '7074696F6E732E6C696E6557696474683B0A202020202020746869732E726164697573203D2028746869732E617661696C61626C65486569676874202D20746869732E6C696E655769647468202F203229202F2028312E30202B20746869732E65787472';
wwv_flow_api.g_varchar2_table(148) := '6150616464696E67293B0A202020202020746869732E6374782E636C6561725265637428302C20302C20746869732E63616E7661732E77696474682C20746869732E63616E7661732E686569676874293B0A202020202020726566203D20746869732E67';
wwv_flow_api.g_varchar2_table(149) := '703B0A202020202020666F7220286A203D20302C206C656E203D207265662E6C656E6774683B206A203C206C656E3B206A2B2B29207B0A20202020202020206761756765203D207265665B6A5D3B0A202020202020202067617567652E7365744F707469';
wwv_flow_api.g_varchar2_table(150) := '6F6E7328746869732E6F7074696F6E732E706F696E746572293B0A202020202020202067617567652E72656E64657228293B0A2020202020207D0A202020202020746869732E72656E64657228293B0A20202020202072657475726E20746869733B0A20';
wwv_flow_api.g_varchar2_table(151) := '2020207D3B0A0A2020202047617567652E70726F746F747970652E636F6E66696750657263656E74436F6C6F7273203D2066756E6374696F6E2829207B0A202020202020766172206276616C2C206776616C2C20692C206A2C207265662C20726573756C';
wwv_flow_api.g_varchar2_table(152) := '74732C207276616C3B0A202020202020746869732E70657263656E74436F6C6F7273203D206E756C6C3B0A20202020202069662028746869732E6F7074696F6E732E70657263656E74436F6C6F727320213D3D20766F6964203029207B0A202020202020';
wwv_flow_api.g_varchar2_table(153) := '2020746869732E70657263656E74436F6C6F7273203D206E657720417272617928293B0A2020202020202020726573756C7473203D205B5D3B0A2020202020202020666F72202869203D206A203D20302C20726566203D20746869732E6F7074696F6E73';
wwv_flow_api.g_varchar2_table(154) := '2E70657263656E74436F6C6F72732E6C656E677468202D20313B2030203C3D20726566203F206A203C3D20726566203A206A203E3D207265663B2069203D2030203C3D20726566203F202B2B6A203A202D2D6A29207B0A20202020202020202020727661';
wwv_flow_api.g_varchar2_table(155) := '6C203D207061727365496E74282863757448657828746869732E6F7074696F6E732E70657263656E74436F6C6F72735B695D5B315D29292E737562737472696E6728302C2032292C203136293B0A202020202020202020206776616C203D207061727365';
wwv_flow_api.g_varchar2_table(156) := '496E74282863757448657828746869732E6F7074696F6E732E70657263656E74436F6C6F72735B695D5B315D29292E737562737472696E6728322C2034292C203136293B0A202020202020202020206276616C203D207061727365496E74282863757448';
wwv_flow_api.g_varchar2_table(157) := '657828746869732E6F7074696F6E732E70657263656E74436F6C6F72735B695D5B315D29292E737562737472696E6728342C2036292C203136293B0A20202020202020202020726573756C74732E7075736828746869732E70657263656E74436F6C6F72';
wwv_flow_api.g_varchar2_table(158) := '735B695D203D207B0A2020202020202020202020207063743A20746869732E6F7074696F6E732E70657263656E74436F6C6F72735B695D5B305D2C0A202020202020202020202020636F6C6F723A207B0A2020202020202020202020202020723A207276';
wwv_flow_api.g_varchar2_table(159) := '616C2C0A2020202020202020202020202020673A206776616C2C0A2020202020202020202020202020623A206276616C0A2020202020202020202020207D0A202020202020202020207D293B0A20202020202020207D0A20202020202020207265747572';
wwv_flow_api.g_varchar2_table(160) := '6E20726573756C74733B0A2020202020207D0A202020207D3B0A0A2020202047617567652E70726F746F747970652E736574203D2066756E6374696F6E2876616C756529207B0A2020202020207661722067702C20692C206A2C206B2C206C2C206C656E';
wwv_flow_api.g_varchar2_table(161) := '2C207265662C20726566312C2076616C3B0A20202020202069662028212876616C756520696E7374616E63656F662041727261792929207B0A202020202020202076616C7565203D205B76616C75655D3B0A2020202020207D0A202020202020666F7220';
wwv_flow_api.g_varchar2_table(162) := '2869203D206A203D20302C20726566203D2076616C75652E6C656E677468202D20313B2030203C3D20726566203F206A203C3D20726566203A206A203E3D207265663B2069203D2030203C3D20726566203F202B2B6A203A202D2D6A29207B0A20202020';
wwv_flow_api.g_varchar2_table(163) := '2020202076616C75655B695D203D20746869732E706172736556616C75652876616C75655B695D293B0A2020202020207D0A2020202020206966202876616C75652E6C656E677468203E20746869732E67702E6C656E67746829207B0A20202020202020';
wwv_flow_api.g_varchar2_table(164) := '20666F72202869203D206B203D20302C2072656631203D2076616C75652E6C656E677468202D20746869732E67702E6C656E6774683B2030203C3D2072656631203F206B203C2072656631203A206B203E20726566313B2069203D2030203C3D20726566';
wwv_flow_api.g_varchar2_table(165) := '31203F202B2B6B203A202D2D6B29207B0A202020202020202020206770203D206E6577204761756765506F696E7465722874686973293B0A2020202020202020202067702E7365744F7074696F6E7328746869732E6F7074696F6E732E706F696E746572';
wwv_flow_api.g_varchar2_table(166) := '293B0A20202020202020202020746869732E67702E70757368286770293B0A20202020202020207D0A2020202020207D20656C7365206966202876616C75652E6C656E677468203C20746869732E67702E6C656E67746829207B0A202020202020202074';
wwv_flow_api.g_varchar2_table(167) := '6869732E6770203D20746869732E67702E736C69636528746869732E67702E6C656E677468202D2076616C75652E6C656E677468293B0A2020202020207D0A20202020202069203D20303B0A202020202020666F7220286C203D20302C206C656E203D20';
wwv_flow_api.g_varchar2_table(168) := '76616C75652E6C656E6774683B206C203C206C656E3B206C2B2B29207B0A202020202020202076616C203D2076616C75655B6C5D3B0A20202020202020206966202876616C203E20746869732E6D617856616C756529207B0A2020202020202020202069';
wwv_flow_api.g_varchar2_table(169) := '662028746869732E6F7074696F6E732E6C696D69744D617829207B0A20202020202020202020202076616C203D20746869732E6D617856616C75653B0A202020202020202020207D20656C7365207B0A202020202020202020202020746869732E6D6178';
wwv_flow_api.g_varchar2_table(170) := '56616C7565203D2076616C202B20313B0A202020202020202020207D0A20202020202020207D20656C7365206966202876616C203C20746869732E6D696E56616C756529207B0A2020202020202020202069662028746869732E6F7074696F6E732E6C69';
wwv_flow_api.g_varchar2_table(171) := '6D69744D696E29207B0A20202020202020202020202076616C203D20746869732E6D696E56616C75653B0A202020202020202020207D20656C7365207B0A202020202020202020202020746869732E6D696E56616C7565203D2076616C202D20313B0A20';
wwv_flow_api.g_varchar2_table(172) := '2020202020202020207D0A20202020202020207D0A2020202020202020746869732E67705B695D2E76616C7565203D2076616C3B0A2020202020202020746869732E67705B692B2B5D2E7365744F7074696F6E73287B0A202020202020202020206D696E';
wwv_flow_api.g_varchar2_table(173) := '56616C75653A20746869732E6D696E56616C75652C0A202020202020202020206D617856616C75653A20746869732E6D617856616C75652C0A20202020202020202020616E676C653A20746869732E6F7074696F6E732E616E676C650A20202020202020';
wwv_flow_api.g_varchar2_table(174) := '207D293B0A2020202020207D0A202020202020746869732E76616C7565203D204D6174682E6D6178284D6174682E6D696E2876616C75655B76616C75652E6C656E677468202D20315D2C20746869732E6D617856616C7565292C20746869732E6D696E56';
wwv_flow_api.g_varchar2_table(175) := '616C7565293B0A202020202020416E696D6174696F6E557064617465722E72756E28746869732E666F726365557064617465293B0A20202020202072657475726E20746869732E666F726365557064617465203D2066616C73653B0A202020207D3B0A0A';
wwv_flow_api.g_varchar2_table(176) := '2020202047617567652E70726F746F747970652E676574416E676C65203D2066756E6374696F6E2876616C756529207B0A20202020202072657475726E202831202B20746869732E6F7074696F6E732E616E676C6529202A204D6174682E5049202B2028';
wwv_flow_api.g_varchar2_table(177) := '2876616C7565202D20746869732E6D696E56616C756529202F2028746869732E6D617856616C7565202D20746869732E6D696E56616C75652929202A202831202D20746869732E6F7074696F6E732E616E676C65202A203229202A204D6174682E50493B';
wwv_flow_api.g_varchar2_table(178) := '0A202020207D3B0A0A2020202047617567652E70726F746F747970652E676574436F6C6F72466F7250657263656E74616765203D2066756E6374696F6E287063742C206772616429207B0A20202020202076617220636F6C6F722C20656E64436F6C6F72';
wwv_flow_api.g_varchar2_table(179) := '2C20692C206A2C2072616E67655063742C207265662C207374617274436F6C6F723B0A20202020202069662028706374203D3D3D203029207B0A2020202020202020636F6C6F72203D20746869732E70657263656E74436F6C6F72735B305D2E636F6C6F';
wwv_flow_api.g_varchar2_table(180) := '723B0A2020202020207D20656C7365207B0A2020202020202020636F6C6F72203D20746869732E70657263656E74436F6C6F72735B746869732E70657263656E74436F6C6F72732E6C656E677468202D20315D2E636F6C6F723B0A202020202020202066';
wwv_flow_api.g_varchar2_table(181) := '6F72202869203D206A203D20302C20726566203D20746869732E70657263656E74436F6C6F72732E6C656E677468202D20313B2030203C3D20726566203F206A203C3D20726566203A206A203E3D207265663B2069203D2030203C3D20726566203F202B';
wwv_flow_api.g_varchar2_table(182) := '2B6A203A202D2D6A29207B0A2020202020202020202069662028706374203C3D20746869732E70657263656E74436F6C6F72735B695D2E70637429207B0A2020202020202020202020206966202867726164203D3D3D207472756529207B0A2020202020';
wwv_flow_api.g_varchar2_table(183) := '2020202020202020207374617274436F6C6F72203D20746869732E70657263656E74436F6C6F72735B69202D20315D207C7C20746869732E70657263656E74436F6C6F72735B305D3B0A2020202020202020202020202020656E64436F6C6F72203D2074';
wwv_flow_api.g_varchar2_table(184) := '6869732E70657263656E74436F6C6F72735B695D3B0A202020202020202020202020202072616E6765506374203D2028706374202D207374617274436F6C6F722E70637429202F2028656E64436F6C6F722E706374202D207374617274436F6C6F722E70';
wwv_flow_api.g_varchar2_table(185) := '6374293B0A2020202020202020202020202020636F6C6F72203D207B0A20202020202020202020202020202020723A204D6174682E666C6F6F72287374617274436F6C6F722E636F6C6F722E72202A202831202D2072616E676550637429202B20656E64';
wwv_flow_api.g_varchar2_table(186) := '436F6C6F722E636F6C6F722E72202A2072616E6765506374292C0A20202020202020202020202020202020673A204D6174682E666C6F6F72287374617274436F6C6F722E636F6C6F722E67202A202831202D2072616E676550637429202B20656E64436F';
wwv_flow_api.g_varchar2_table(187) := '6C6F722E636F6C6F722E67202A2072616E6765506374292C0A20202020202020202020202020202020623A204D6174682E666C6F6F72287374617274436F6C6F722E636F6C6F722E62202A202831202D2072616E676550637429202B20656E64436F6C6F';
wwv_flow_api.g_varchar2_table(188) := '722E636F6C6F722E62202A2072616E6765506374290A20202020202020202020202020207D3B0A2020202020202020202020207D20656C7365207B0A2020202020202020202020202020636F6C6F72203D20746869732E70657263656E74436F6C6F7273';
wwv_flow_api.g_varchar2_table(189) := '5B695D2E636F6C6F723B0A2020202020202020202020207D0A202020202020202020202020627265616B3B0A202020202020202020207D0A20202020202020207D0A2020202020207D0A20202020202072657475726E20277267622827202B205B636F6C';
wwv_flow_api.g_varchar2_table(190) := '6F722E722C20636F6C6F722E672C20636F6C6F722E625D2E6A6F696E28272C2729202B202729273B0A202020207D3B0A0A2020202047617567652E70726F746F747970652E676574436F6C6F72466F7256616C7565203D2066756E6374696F6E2876616C';
wwv_flow_api.g_varchar2_table(191) := '2C206772616429207B0A202020202020766172207063743B0A202020202020706374203D202876616C202D20746869732E6D696E56616C756529202F2028746869732E6D617856616C7565202D20746869732E6D696E56616C7565293B0A202020202020';
wwv_flow_api.g_varchar2_table(192) := '72657475726E20746869732E676574436F6C6F72466F7250657263656E74616765287063742C2067726164293B0A202020207D3B0A0A2020202047617567652E70726F746F747970652E72656E6465725374617469634C6162656C73203D2066756E6374';
wwv_flow_api.g_varchar2_table(193) := '696F6E287374617469634C6162656C732C20772C20682C2072616469757329207B0A20202020202076617220666F6E742C20666F6E7473697A652C206A2C206C656E2C206D617463682C2072652C207265662C20726573742C20726F746174696F6E416E';
wwv_flow_api.g_varchar2_table(194) := '676C652C2076616C75653B0A202020202020746869732E6374782E7361766528293B0A202020202020746869732E6374782E7472616E736C61746528772C2068293B0A202020202020666F6E74203D207374617469634C6162656C732E666F6E74207C7C';
wwv_flow_api.g_varchar2_table(195) := '2022313070782054696D6573223B0A2020202020207265203D202F5C642B5C2E3F5C643F2F3B0A2020202020206D61746368203D20666F6E742E6D61746368287265295B305D3B0A20202020202072657374203D20666F6E742E736C696365286D617463';
wwv_flow_api.g_varchar2_table(196) := '682E6C656E677468293B0A202020202020666F6E7473697A65203D207061727365466C6F6174286D6174636829202A20746869732E646973706C61795363616C653B0A202020202020746869732E6374782E666F6E74203D20666F6E7473697A65202B20';
wwv_flow_api.g_varchar2_table(197) := '726573743B0A202020202020746869732E6374782E66696C6C5374796C65203D207374617469634C6162656C732E636F6C6F72207C7C202223303030303030223B0A202020202020746869732E6374782E74657874426173656C696E65203D2022626F74';
wwv_flow_api.g_varchar2_table(198) := '746F6D223B0A202020202020746869732E6374782E74657874416C69676E203D202263656E746572223B0A202020202020726566203D207374617469634C6162656C732E6C6162656C733B0A202020202020666F7220286A203D20302C206C656E203D20';
wwv_flow_api.g_varchar2_table(199) := '7265662E6C656E6774683B206A203C206C656E3B206A2B2B29207B0A202020202020202076616C7565203D207265665B6A5D3B0A20202020202020206966202876616C75652E6C6162656C20213D3D20766F6964203029207B0A20202020202020202020';
wwv_flow_api.g_varchar2_table(200) := '696620282821746869732E6F7074696F6E732E6C696D69744D696E207C7C2076616C7565203E3D20746869732E6D696E56616C756529202626202821746869732E6F7074696F6E732E6C696D69744D6178207C7C2076616C7565203C3D20746869732E6D';
wwv_flow_api.g_varchar2_table(201) := '617856616C75652929207B0A202020202020202020202020666F6E74203D2076616C75652E666F6E74207C7C207374617469634C6162656C732E666F6E743B0A2020202020202020202020206D61746368203D20666F6E742E6D61746368287265295B30';
wwv_flow_api.g_varchar2_table(202) := '5D3B0A20202020202020202020202072657374203D20666F6E742E736C696365286D617463682E6C656E677468293B0A202020202020202020202020666F6E7473697A65203D207061727365466C6F6174286D6174636829202A20746869732E64697370';
wwv_flow_api.g_varchar2_table(203) := '6C61795363616C653B0A202020202020202020202020746869732E6374782E666F6E74203D20666F6E7473697A65202B20726573743B0A202020202020202020202020726F746174696F6E416E676C65203D20746869732E676574416E676C652876616C';
wwv_flow_api.g_varchar2_table(204) := '75652E6C6162656C29202D2033202A204D6174682E5049202F20323B0A202020202020202020202020746869732E6374782E726F7461746528726F746174696F6E416E676C65293B0A202020202020202020202020746869732E6374782E66696C6C5465';
wwv_flow_api.g_varchar2_table(205) := '787428666F726D61744E756D6265722876616C75652E6C6162656C2C207374617469634C6162656C732E6672616374696F6E446967697473292C20302C202D726164697573202D20746869732E6C696E655769647468202F2032293B0A20202020202020';
wwv_flow_api.g_varchar2_table(206) := '2020202020746869732E6374782E726F74617465282D726F746174696F6E416E676C65293B0A202020202020202020207D0A20202020202020207D20656C7365207B0A20202020202020202020696620282821746869732E6F7074696F6E732E6C696D69';
wwv_flow_api.g_varchar2_table(207) := '744D696E207C7C2076616C7565203E3D20746869732E6D696E56616C756529202626202821746869732E6F7074696F6E732E6C696D69744D6178207C7C2076616C7565203C3D20746869732E6D617856616C75652929207B0A2020202020202020202020';
wwv_flow_api.g_varchar2_table(208) := '20726F746174696F6E416E676C65203D20746869732E676574416E676C652876616C756529202D2033202A204D6174682E5049202F20323B0A202020202020202020202020746869732E6374782E726F7461746528726F746174696F6E416E676C65293B';
wwv_flow_api.g_varchar2_table(209) := '0A202020202020202020202020746869732E6374782E66696C6C5465787428666F726D61744E756D6265722876616C75652C207374617469634C6162656C732E6672616374696F6E446967697473292C20302C202D726164697573202D20746869732E6C';
wwv_flow_api.g_varchar2_table(210) := '696E655769647468202F2032293B0A202020202020202020202020746869732E6374782E726F74617465282D726F746174696F6E416E676C65293B0A202020202020202020207D0A20202020202020207D0A2020202020207D0A20202020202072657475';
wwv_flow_api.g_varchar2_table(211) := '726E20746869732E6374782E726573746F726528293B0A202020207D3B0A0A2020202047617567652E70726F746F747970652E72656E6465725469636B73203D2066756E6374696F6E287469636B734F7074696F6E732C20772C20682C20726164697573';
wwv_flow_api.g_varchar2_table(212) := '29207B0A2020202020207661722063757272656E744469766973696F6E2C2063757272656E745375624469766973696F6E2C20646976436F6C6F722C206469764C656E6774682C2064697657696474682C206469766973696F6E436F756E742C206A2C20';
wwv_flow_api.g_varchar2_table(213) := '6C696E6557696474682C2072616E67652C2072616E67654469766973696F6E732C207265662C20726573756C74732C207363616C654D75746174652C2073742C20737562436F6C6F722C207375624469766973696F6E732C207375624C656E6774682C20';
wwv_flow_api.g_varchar2_table(214) := '73756257696474682C207375626469766973696F6E436F756E742C20742C20746D705261646975733B0A202020202020696620287469636B734F7074696F6E7320213D3D207B7D29207B0A20202020202020206469766973696F6E436F756E74203D2074';
wwv_flow_api.g_varchar2_table(215) := '69636B734F7074696F6E732E6469766973696F6E73207C7C20303B0A20202020202020207375626469766973696F6E436F756E74203D207469636B734F7074696F6E732E7375624469766973696F6E73207C7C20303B0A2020202020202020646976436F';
wwv_flow_api.g_varchar2_table(216) := '6C6F72203D207469636B734F7074696F6E732E646976436F6C6F72207C7C202723666666273B0A2020202020202020737562436F6C6F72203D207469636B734F7074696F6E732E737562436F6C6F72207C7C202723666666273B0A202020202020202064';
wwv_flow_api.g_varchar2_table(217) := '69764C656E677468203D207469636B734F7074696F6E732E6469764C656E677468207C7C20302E373B0A20202020202020207375624C656E677468203D207469636B734F7074696F6E732E7375624C656E677468207C7C20302E323B0A20202020202020';
wwv_flow_api.g_varchar2_table(218) := '2072616E6765203D207061727365466C6F617428746869732E6D617856616C756529202D207061727365466C6F617428746869732E6D696E56616C7565293B0A202020202020202072616E67654469766973696F6E73203D207061727365466C6F617428';
wwv_flow_api.g_varchar2_table(219) := '72616E676529202F207061727365466C6F6174287469636B734F7074696F6E732E6469766973696F6E73293B0A20202020202020207375624469766973696F6E73203D207061727365466C6F61742872616E67654469766973696F6E7329202F20706172';
wwv_flow_api.g_varchar2_table(220) := '7365466C6F6174287469636B734F7074696F6E732E7375624469766973696F6E73293B0A202020202020202063757272656E744469766973696F6E203D207061727365466C6F617428746869732E6D696E56616C7565293B0A2020202020202020637572';
wwv_flow_api.g_varchar2_table(221) := '72656E745375624469766973696F6E203D20302E30202B207375624469766973696F6E733B0A20202020202020206C696E655769647468203D2072616E6765202F203430303B0A20202020202020206469765769647468203D206C696E65576964746820';
wwv_flow_api.g_varchar2_table(222) := '2A20287469636B734F7074696F6E732E6469765769647468207C7C2031293B0A20202020202020207375625769647468203D206C696E655769647468202A20287469636B734F7074696F6E732E7375625769647468207C7C2031293B0A20202020202020';
wwv_flow_api.g_varchar2_table(223) := '20726573756C7473203D205B5D3B0A2020202020202020666F72202874203D206A203D20302C20726566203D206469766973696F6E436F756E74202B20313B206A203C207265663B2074203D206A202B3D203129207B0A20202020202020202020746869';
wwv_flow_api.g_varchar2_table(224) := '732E6374782E6C696E655769647468203D20746869732E6C696E655769647468202A206469764C656E6774683B0A202020202020202020207363616C654D7574617465203D2028746869732E6C696E655769647468202F203229202A202831202D206469';
wwv_flow_api.g_varchar2_table(225) := '764C656E677468293B0A20202020202020202020746D70526164697573203D2028746869732E726164697573202A20746869732E6F7074696F6E732E7261646975735363616C6529202B207363616C654D75746174653B0A202020202020202020207468';
wwv_flow_api.g_varchar2_table(226) := '69732E6374782E7374726F6B655374796C65203D20646976436F6C6F723B0A20202020202020202020746869732E6374782E626567696E5061746828293B0A20202020202020202020746869732E6374782E61726328302C20302C20746D705261646975';
wwv_flow_api.g_varchar2_table(227) := '732C20746869732E676574416E676C652863757272656E744469766973696F6E202D206469765769647468292C20746869732E676574416E676C652863757272656E744469766973696F6E202B206469765769647468292C2066616C7365293B0A202020';
wwv_flow_api.g_varchar2_table(228) := '20202020202020746869732E6374782E7374726F6B6528293B0A2020202020202020202063757272656E745375624469766973696F6E203D2063757272656E744469766973696F6E202B207375624469766973696F6E733B0A2020202020202020202063';
wwv_flow_api.g_varchar2_table(229) := '757272656E744469766973696F6E202B3D2072616E67654469766973696F6E733B0A20202020202020202020696620287420213D3D207469636B734F7074696F6E732E6469766973696F6E73202626207375626469766973696F6E436F756E74203E2030';
wwv_flow_api.g_varchar2_table(230) := '29207B0A202020202020202020202020726573756C74732E70757368282866756E6374696F6E2829207B0A2020202020202020202020202020766172206B2C20726566312C20726573756C7473313B0A2020202020202020202020202020726573756C74';
wwv_flow_api.g_varchar2_table(231) := '7331203D205B5D3B0A2020202020202020202020202020666F7220287374203D206B203D20302C2072656631203D207375626469766973696F6E436F756E74202D20313B206B203C20726566313B207374203D206B202B3D203129207B0A202020202020';
wwv_flow_api.g_varchar2_table(232) := '20202020202020202020746869732E6374782E6C696E655769647468203D20746869732E6C696E655769647468202A207375624C656E6774683B0A202020202020202020202020202020207363616C654D7574617465203D2028746869732E6C696E6557';
wwv_flow_api.g_varchar2_table(233) := '69647468202F203229202A202831202D207375624C656E677468293B0A20202020202020202020202020202020746D70526164697573203D2028746869732E726164697573202A20746869732E6F7074696F6E732E7261646975735363616C6529202B20';
wwv_flow_api.g_varchar2_table(234) := '7363616C654D75746174653B0A20202020202020202020202020202020746869732E6374782E7374726F6B655374796C65203D20737562436F6C6F723B0A20202020202020202020202020202020746869732E6374782E626567696E5061746828293B0A';
wwv_flow_api.g_varchar2_table(235) := '20202020202020202020202020202020746869732E6374782E61726328302C20302C20746D705261646975732C20746869732E676574416E676C652863757272656E745375624469766973696F6E202D207375625769647468292C20746869732E676574';
wwv_flow_api.g_varchar2_table(236) := '416E676C652863757272656E745375624469766973696F6E202B207375625769647468292C2066616C7365293B0A20202020202020202020202020202020746869732E6374782E7374726F6B6528293B0A20202020202020202020202020202020726573';
wwv_flow_api.g_varchar2_table(237) := '756C7473312E707573682863757272656E745375624469766973696F6E202B3D207375624469766973696F6E73293B0A20202020202020202020202020207D0A202020202020202020202020202072657475726E20726573756C7473313B0A2020202020';
wwv_flow_api.g_varchar2_table(238) := '202020202020207D292E63616C6C287468697329293B0A202020202020202020207D20656C7365207B0A202020202020202020202020726573756C74732E7075736828766F69642030293B0A202020202020202020207D0A20202020202020207D0A2020';
wwv_flow_api.g_varchar2_table(239) := '20202020202072657475726E20726573756C74733B0A2020202020207D0A202020207D3B0A0A2020202047617567652E70726F746F747970652E72656E646572203D2066756E6374696F6E2829207B0A20202020202076617220646973706C6179656441';
wwv_flow_api.g_varchar2_table(240) := '6E676C652C2066696C6C5374796C652C2067617567652C20682C206A2C206B2C206C656E2C206C656E312C206D61782C206D696E2C207261646975732C207265662C20726566312C207363616C654D75746174652C20746D705261646975732C20772C20';
wwv_flow_api.g_varchar2_table(241) := '7A6F6E653B0A20202020202077203D20746869732E63616E7661732E7769647468202F20323B0A20202020202068203D2028746869732E63616E7661732E686569676874202A20746869732E70616464696E67546F70202B20746869732E617661696C61';
wwv_flow_api.g_varchar2_table(242) := '626C6548656967687429202D202828746869732E726164697573202B20746869732E6C696E655769647468202F203229202A20746869732E657874726150616464696E67293B0A202020202020646973706C61796564416E676C65203D20746869732E67';
wwv_flow_api.g_varchar2_table(243) := '6574416E676C6528746869732E646973706C6179656456616C7565293B0A20202020202069662028746869732E746578744669656C6429207B0A2020202020202020746869732E746578744669656C642E72656E6465722874686973293B0A2020202020';
wwv_flow_api.g_varchar2_table(244) := '207D0A202020202020746869732E6374782E6C696E65436170203D202262757474223B0A202020202020726164697573203D20746869732E726164697573202A20746869732E6F7074696F6E732E7261646975735363616C653B0A202020202020696620';
wwv_flow_api.g_varchar2_table(245) := '28746869732E6F7074696F6E732E7374617469634C6162656C7329207B0A2020202020202020746869732E72656E6465725374617469634C6162656C7328746869732E6F7074696F6E732E7374617469634C6162656C732C20772C20682C207261646975';
wwv_flow_api.g_varchar2_table(246) := '73293B0A2020202020207D0A20202020202069662028746869732E6F7074696F6E732E7374617469635A6F6E657329207B0A2020202020202020746869732E6374782E7361766528293B0A2020202020202020746869732E6374782E7472616E736C6174';
wwv_flow_api.g_varchar2_table(247) := '6528772C2068293B0A2020202020202020746869732E6374782E6C696E655769647468203D20746869732E6C696E6557696474683B0A2020202020202020726566203D20746869732E6F7074696F6E732E7374617469635A6F6E65733B0A202020202020';
wwv_flow_api.g_varchar2_table(248) := '2020666F7220286A203D20302C206C656E203D207265662E6C656E6774683B206A203C206C656E3B206A2B2B29207B0A202020202020202020207A6F6E65203D207265665B6A5D3B0A202020202020202020206D696E203D207A6F6E652E6D696E3B0A20';
wwv_flow_api.g_varchar2_table(249) := '20202020202020202069662028746869732E6F7074696F6E732E6C696D69744D696E202626206D696E203C20746869732E6D696E56616C756529207B0A2020202020202020202020206D696E203D20746869732E6D696E56616C75653B0A202020202020';
wwv_flow_api.g_varchar2_table(250) := '202020207D0A202020202020202020206D6178203D207A6F6E652E6D61783B0A2020202020202020202069662028746869732E6F7074696F6E732E6C696D69744D6178202626206D6178203E20746869732E6D617856616C756529207B0A202020202020';
wwv_flow_api.g_varchar2_table(251) := '2020202020206D6178203D20746869732E6D617856616C75653B0A202020202020202020207D0A20202020202020202020746D70526164697573203D20746869732E726164697573202A20746869732E6F7074696F6E732E7261646975735363616C653B';
wwv_flow_api.g_varchar2_table(252) := '0A20202020202020202020696620287A6F6E652E68656967687429207B0A202020202020202020202020746869732E6374782E6C696E655769647468203D20746869732E6C696E655769647468202A207A6F6E652E6865696768743B0A20202020202020';
wwv_flow_api.g_varchar2_table(253) := '20202020207363616C654D7574617465203D2028746869732E6C696E655769647468202F203229202A20287A6F6E652E6F6666736574207C7C2031202D207A6F6E652E686569676874293B0A202020202020202020202020746D70526164697573203D20';
wwv_flow_api.g_varchar2_table(254) := '28746869732E726164697573202A20746869732E6F7074696F6E732E7261646975735363616C6529202B207363616C654D75746174653B0A202020202020202020207D0A20202020202020202020746869732E6374782E7374726F6B655374796C65203D';
wwv_flow_api.g_varchar2_table(255) := '207A6F6E652E7374726F6B655374796C653B0A20202020202020202020746869732E6374782E626567696E5061746828293B0A20202020202020202020746869732E6374782E61726328302C20302C20746D705261646975732C20746869732E67657441';
wwv_flow_api.g_varchar2_table(256) := '6E676C65286D696E292C20746869732E676574416E676C65286D6178292C2066616C7365293B0A20202020202020202020746869732E6374782E7374726F6B6528293B0A20202020202020207D0A2020202020207D20656C7365207B0A20202020202020';
wwv_flow_api.g_varchar2_table(257) := '2069662028746869732E6F7074696F6E732E637573746F6D46696C6C5374796C6520213D3D20766F6964203029207B0A2020202020202020202066696C6C5374796C65203D20746869732E6F7074696F6E732E637573746F6D46696C6C5374796C652874';
wwv_flow_api.g_varchar2_table(258) := '686973293B0A20202020202020207D20656C73652069662028746869732E70657263656E74436F6C6F727320213D3D206E756C6C29207B0A2020202020202020202066696C6C5374796C65203D20746869732E676574436F6C6F72466F7256616C756528';
wwv_flow_api.g_varchar2_table(259) := '746869732E646973706C6179656456616C75652C20746869732E6F7074696F6E732E67656E65726174654772616469656E74293B0A20202020202020207D20656C73652069662028746869732E6F7074696F6E732E636F6C6F7253746F7020213D3D2076';
wwv_flow_api.g_varchar2_table(260) := '6F6964203029207B0A2020202020202020202069662028746869732E6F7074696F6E732E6772616469656E7454797065203D3D3D203029207B0A20202020202020202020202066696C6C5374796C65203D20746869732E6374782E637265617465526164';
wwv_flow_api.g_varchar2_table(261) := '69616C4772616469656E7428772C20682C20392C20772C20682C203730293B0A202020202020202020207D20656C7365207B0A20202020202020202020202066696C6C5374796C65203D20746869732E6374782E6372656174654C696E65617247726164';
wwv_flow_api.g_varchar2_table(262) := '69656E7428302C20302C20772C2030293B0A202020202020202020207D0A2020202020202020202066696C6C5374796C652E616464436F6C6F7253746F7028302C20746869732E6F7074696F6E732E636F6C6F725374617274293B0A2020202020202020';
wwv_flow_api.g_varchar2_table(263) := '202066696C6C5374796C652E616464436F6C6F7253746F7028312C20746869732E6F7074696F6E732E636F6C6F7253746F70293B0A20202020202020207D20656C7365207B0A2020202020202020202066696C6C5374796C65203D20746869732E6F7074';
wwv_flow_api.g_varchar2_table(264) := '696F6E732E636F6C6F7253746172743B0A20202020202020207D0A2020202020202020746869732E6374782E7374726F6B655374796C65203D2066696C6C5374796C653B0A2020202020202020746869732E6374782E626567696E5061746828293B0A20';
wwv_flow_api.g_varchar2_table(265) := '20202020202020746869732E6374782E61726328772C20682C207261646975732C202831202B20746869732E6F7074696F6E732E616E676C6529202A204D6174682E50492C20646973706C61796564416E676C652C2066616C7365293B0A202020202020';
wwv_flow_api.g_varchar2_table(266) := '2020746869732E6374782E6C696E655769647468203D20746869732E6C696E6557696474683B0A2020202020202020746869732E6374782E7374726F6B6528293B0A2020202020202020746869732E6374782E7374726F6B655374796C65203D20746869';
wwv_flow_api.g_varchar2_table(267) := '732E6F7074696F6E732E7374726F6B65436F6C6F723B0A2020202020202020746869732E6374782E626567696E5061746828293B0A2020202020202020746869732E6374782E61726328772C20682C207261646975732C20646973706C61796564416E67';
wwv_flow_api.g_varchar2_table(268) := '6C652C202832202D20746869732E6F7074696F6E732E616E676C6529202A204D6174682E50492C2066616C7365293B0A2020202020202020746869732E6374782E7374726F6B6528293B0A2020202020202020746869732E6374782E7361766528293B0A';
wwv_flow_api.g_varchar2_table(269) := '2020202020202020746869732E6374782E7472616E736C61746528772C2068293B0A2020202020207D0A20202020202069662028746869732E6F7074696F6E732E72656E6465725469636B7329207B0A2020202020202020746869732E72656E64657254';
wwv_flow_api.g_varchar2_table(270) := '69636B7328746869732E6F7074696F6E732E72656E6465725469636B732C20772C20682C20726164697573293B0A2020202020207D0A202020202020746869732E6374782E726573746F726528293B0A202020202020746869732E6374782E7472616E73';
wwv_flow_api.g_varchar2_table(271) := '6C61746528772C2068293B0A20202020202072656631203D20746869732E67703B0A202020202020666F7220286B203D20302C206C656E31203D20726566312E6C656E6774683B206B203C206C656E313B206B2B2B29207B0A2020202020202020676175';
wwv_flow_api.g_varchar2_table(272) := '6765203D20726566315B6B5D3B0A202020202020202067617567652E7570646174652874727565293B0A2020202020207D0A20202020202072657475726E20746869732E6374782E7472616E736C617465282D772C202D68293B0A202020207D3B0A0A20';
wwv_flow_api.g_varchar2_table(273) := '20202072657475726E2047617567653B0A0A20207D2928426173654761756765293B0A0A202042617365446F6E7574203D202866756E6374696F6E287375706572436C61737329207B0A20202020657874656E642842617365446F6E75742C2073757065';
wwv_flow_api.g_varchar2_table(274) := '72436C617373293B0A0A2020202042617365446F6E75742E70726F746F747970652E6C696E655769647468203D2031353B0A0A2020202042617365446F6E75742E70726F746F747970652E646973706C6179656456616C7565203D20303B0A0A20202020';
wwv_flow_api.g_varchar2_table(275) := '42617365446F6E75742E70726F746F747970652E76616C7565203D2033333B0A0A2020202042617365446F6E75742E70726F746F747970652E6D617856616C7565203D2038303B0A0A2020202042617365446F6E75742E70726F746F747970652E6D696E';
wwv_flow_api.g_varchar2_table(276) := '56616C7565203D20303B0A0A2020202042617365446F6E75742E70726F746F747970652E6F7074696F6E73203D207B0A2020202020206C696E6557696474683A20302E31302C0A202020202020636F6C6F7253746172743A202223366636656130222C0A';
wwv_flow_api.g_varchar2_table(277) := '202020202020636F6C6F7253746F703A202223633063306462222C0A2020202020207374726F6B65436F6C6F723A202223656565656565222C0A202020202020736861646F77436F6C6F723A202223643564356435222C0A202020202020616E676C653A';
wwv_flow_api.g_varchar2_table(278) := '20302E33352C0A2020202020207261646975735363616C653A20312E300A202020207D3B0A0A2020202066756E6374696F6E2042617365446F6E75742863616E76617329207B0A202020202020746869732E63616E766173203D2063616E7661733B0A20';
wwv_flow_api.g_varchar2_table(279) := '202020202042617365446F6E75742E5F5F73757065725F5F2E636F6E7374727563746F722E63616C6C2874686973293B0A20202020202069662028747970656F6620475F766D6C43616E7661734D616E6167657220213D3D2027756E646566696E656427';
wwv_flow_api.g_varchar2_table(280) := '29207B0A2020202020202020746869732E63616E766173203D2077696E646F772E475F766D6C43616E7661734D616E616765722E696E6974456C656D656E7428746869732E63616E766173293B0A2020202020207D0A202020202020746869732E637478';
wwv_flow_api.g_varchar2_table(281) := '203D20746869732E63616E7661732E676574436F6E746578742827326427293B0A202020202020746869732E7365744F7074696F6E7328293B0A202020202020746869732E72656E64657228293B0A202020207D0A0A2020202042617365446F6E75742E';
wwv_flow_api.g_varchar2_table(282) := '70726F746F747970652E676574416E676C65203D2066756E6374696F6E2876616C756529207B0A20202020202072657475726E202831202D20746869732E6F7074696F6E732E616E676C6529202A204D6174682E5049202B20282876616C7565202D2074';
wwv_flow_api.g_varchar2_table(283) := '6869732E6D696E56616C756529202F2028746869732E6D617856616C7565202D20746869732E6D696E56616C75652929202A20282832202B20746869732E6F7074696F6E732E616E676C6529202D202831202D20746869732E6F7074696F6E732E616E67';
wwv_flow_api.g_varchar2_table(284) := '6C652929202A204D6174682E50493B0A202020207D3B0A0A2020202042617365446F6E75742E70726F746F747970652E7365744F7074696F6E73203D2066756E6374696F6E286F7074696F6E7329207B0A202020202020696620286F7074696F6E73203D';
wwv_flow_api.g_varchar2_table(285) := '3D206E756C6C29207B0A20202020202020206F7074696F6E73203D206E756C6C3B0A2020202020207D0A20202020202042617365446F6E75742E5F5F73757065725F5F2E7365744F7074696F6E732E63616C6C28746869732C206F7074696F6E73293B0A';
wwv_flow_api.g_varchar2_table(286) := '202020202020746869732E6C696E655769647468203D20746869732E63616E7661732E686569676874202A20746869732E6F7074696F6E732E6C696E6557696474683B0A202020202020746869732E726164697573203D20746869732E6F7074696F6E73';
wwv_flow_api.g_varchar2_table(287) := '2E7261646975735363616C65202A2028746869732E63616E7661732E686569676874202F2032202D20746869732E6C696E655769647468202F2032293B0A20202020202072657475726E20746869733B0A202020207D3B0A0A2020202042617365446F6E';
wwv_flow_api.g_varchar2_table(288) := '75742E70726F746F747970652E736574203D2066756E6374696F6E2876616C756529207B0A202020202020746869732E76616C7565203D20746869732E706172736556616C75652876616C7565293B0A20202020202069662028746869732E76616C7565';
wwv_flow_api.g_varchar2_table(289) := '203E20746869732E6D617856616C756529207B0A202020202020202069662028746869732E6F7074696F6E732E6C696D69744D617829207B0A20202020202020202020746869732E76616C7565203D20746869732E6D617856616C75653B0A2020202020';
wwv_flow_api.g_varchar2_table(290) := '2020207D20656C7365207B0A20202020202020202020746869732E6D617856616C7565203D20746869732E76616C75653B0A20202020202020207D0A2020202020207D20656C73652069662028746869732E76616C7565203C20746869732E6D696E5661';
wwv_flow_api.g_varchar2_table(291) := '6C756529207B0A202020202020202069662028746869732E6F7074696F6E732E6C696D69744D696E29207B0A20202020202020202020746869732E76616C7565203D20746869732E6D696E56616C75653B0A20202020202020207D20656C7365207B0A20';
wwv_flow_api.g_varchar2_table(292) := '202020202020202020746869732E6D696E56616C7565203D20746869732E76616C75653B0A20202020202020207D0A2020202020207D0A202020202020416E696D6174696F6E557064617465722E72756E28746869732E666F726365557064617465293B';
wwv_flow_api.g_varchar2_table(293) := '0A20202020202072657475726E20746869732E666F726365557064617465203D2066616C73653B0A202020207D3B0A0A2020202042617365446F6E75742E70726F746F747970652E72656E646572203D2066756E6374696F6E2829207B0A202020202020';
wwv_flow_api.g_varchar2_table(294) := '76617220646973706C61796564416E676C652C2067726446696C6C2C20682C2073746172742C2073746F702C20773B0A202020202020646973706C61796564416E676C65203D20746869732E676574416E676C6528746869732E646973706C6179656456';
wwv_flow_api.g_varchar2_table(295) := '616C7565293B0A20202020202077203D20746869732E63616E7661732E7769647468202F20323B0A20202020202068203D20746869732E63616E7661732E686569676874202F20323B0A20202020202069662028746869732E746578744669656C642920';
wwv_flow_api.g_varchar2_table(296) := '7B0A2020202020202020746869732E746578744669656C642E72656E6465722874686973293B0A2020202020207D0A20202020202067726446696C6C203D20746869732E6374782E63726561746552616469616C4772616469656E7428772C20682C2033';
wwv_flow_api.g_varchar2_table(297) := '392C20772C20682C203730293B0A20202020202067726446696C6C2E616464436F6C6F7253746F7028302C20746869732E6F7074696F6E732E636F6C6F725374617274293B0A20202020202067726446696C6C2E616464436F6C6F7253746F7028312C20';
wwv_flow_api.g_varchar2_table(298) := '746869732E6F7074696F6E732E636F6C6F7253746F70293B0A2020202020207374617274203D20746869732E726164697573202D20746869732E6C696E655769647468202F20323B0A20202020202073746F70203D20746869732E726164697573202B20';
wwv_flow_api.g_varchar2_table(299) := '746869732E6C696E655769647468202F20323B0A202020202020746869732E6374782E7374726F6B655374796C65203D20746869732E6F7074696F6E732E7374726F6B65436F6C6F723B0A202020202020746869732E6374782E626567696E5061746828';
wwv_flow_api.g_varchar2_table(300) := '293B0A202020202020746869732E6374782E61726328772C20682C20746869732E7261646975732C202831202D20746869732E6F7074696F6E732E616E676C6529202A204D6174682E50492C202832202B20746869732E6F7074696F6E732E616E676C65';
wwv_flow_api.g_varchar2_table(301) := '29202A204D6174682E50492C2066616C7365293B0A202020202020746869732E6374782E6C696E655769647468203D20746869732E6C696E6557696474683B0A202020202020746869732E6374782E6C696E65436170203D2022726F756E64223B0A2020';
wwv_flow_api.g_varchar2_table(302) := '20202020746869732E6374782E7374726F6B6528293B0A202020202020746869732E6374782E7374726F6B655374796C65203D2067726446696C6C3B0A202020202020746869732E6374782E626567696E5061746828293B0A202020202020746869732E';
wwv_flow_api.g_varchar2_table(303) := '6374782E61726328772C20682C20746869732E7261646975732C202831202D20746869732E6F7074696F6E732E616E676C6529202A204D6174682E50492C20646973706C61796564416E676C652C2066616C7365293B0A20202020202072657475726E20';
wwv_flow_api.g_varchar2_table(304) := '746869732E6374782E7374726F6B6528293B0A202020207D3B0A0A2020202072657475726E2042617365446F6E75743B0A0A20207D2928426173654761756765293B0A0A2020446F6E7574203D202866756E6374696F6E287375706572436C6173732920';
wwv_flow_api.g_varchar2_table(305) := '7B0A20202020657874656E6428446F6E75742C207375706572436C617373293B0A0A2020202066756E6374696F6E20446F6E75742829207B0A20202020202072657475726E20446F6E75742E5F5F73757065725F5F2E636F6E7374727563746F722E6170';
wwv_flow_api.g_varchar2_table(306) := '706C7928746869732C20617267756D656E7473293B0A202020207D0A0A20202020446F6E75742E70726F746F747970652E7374726F6B654772616469656E74203D2066756E6374696F6E28772C20682C2073746172742C2073746F7029207B0A20202020';
wwv_flow_api.g_varchar2_table(307) := '2020766172206772643B0A202020202020677264203D20746869732E6374782E63726561746552616469616C4772616469656E7428772C20682C2073746172742C20772C20682C2073746F70293B0A2020202020206772642E616464436F6C6F7253746F';
wwv_flow_api.g_varchar2_table(308) := '7028302C20746869732E6F7074696F6E732E736861646F77436F6C6F72293B0A2020202020206772642E616464436F6C6F7253746F7028302E31322C20746869732E6F7074696F6E732E5F6F72675374726F6B65436F6C6F72293B0A2020202020206772';
wwv_flow_api.g_varchar2_table(309) := '642E616464436F6C6F7253746F7028302E38382C20746869732E6F7074696F6E732E5F6F72675374726F6B65436F6C6F72293B0A2020202020206772642E616464436F6C6F7253746F7028312C20746869732E6F7074696F6E732E736861646F77436F6C';
wwv_flow_api.g_varchar2_table(310) := '6F72293B0A20202020202072657475726E206772643B0A202020207D3B0A0A20202020446F6E75742E70726F746F747970652E7365744F7074696F6E73203D2066756E6374696F6E286F7074696F6E7329207B0A20202020202076617220682C20737461';
wwv_flow_api.g_varchar2_table(311) := '72742C2073746F702C20773B0A202020202020696620286F7074696F6E73203D3D206E756C6C29207B0A20202020202020206F7074696F6E73203D206E756C6C3B0A2020202020207D0A202020202020446F6E75742E5F5F73757065725F5F2E7365744F';
wwv_flow_api.g_varchar2_table(312) := '7074696F6E732E63616C6C28746869732C206F7074696F6E73293B0A20202020202077203D20746869732E63616E7661732E7769647468202F20323B0A20202020202068203D20746869732E63616E7661732E686569676874202F20323B0A2020202020';
wwv_flow_api.g_varchar2_table(313) := '207374617274203D20746869732E726164697573202D20746869732E6C696E655769647468202F20323B0A20202020202073746F70203D20746869732E726164697573202B20746869732E6C696E655769647468202F20323B0A20202020202074686973';
wwv_flow_api.g_varchar2_table(314) := '2E6F7074696F6E732E5F6F72675374726F6B65436F6C6F72203D20746869732E6F7074696F6E732E7374726F6B65436F6C6F723B0A202020202020746869732E6F7074696F6E732E7374726F6B65436F6C6F72203D20746869732E7374726F6B65477261';
wwv_flow_api.g_varchar2_table(315) := '6469656E7428772C20682C2073746172742C2073746F70293B0A20202020202072657475726E20746869733B0A202020207D3B0A0A2020202072657475726E20446F6E75743B0A0A20207D292842617365446F6E7574293B0A0A202077696E646F772E41';
wwv_flow_api.g_varchar2_table(316) := '6E696D6174696F6E55706461746572203D207B0A20202020656C656D656E74733A205B5D2C0A20202020616E696D49643A206E756C6C2C0A20202020616464416C6C3A2066756E6374696F6E286C69737429207B0A20202020202076617220656C656D2C';
wwv_flow_api.g_varchar2_table(317) := '206A2C206C656E2C20726573756C74733B0A202020202020726573756C7473203D205B5D3B0A202020202020666F7220286A203D20302C206C656E203D206C6973742E6C656E6774683B206A203C206C656E3B206A2B2B29207B0A202020202020202065';
wwv_flow_api.g_varchar2_table(318) := '6C656D203D206C6973745B6A5D3B0A2020202020202020726573756C74732E7075736828416E696D6174696F6E557064617465722E656C656D656E74732E7075736828656C656D29293B0A2020202020207D0A20202020202072657475726E2072657375';
wwv_flow_api.g_varchar2_table(319) := '6C74733B0A202020207D2C0A202020206164643A2066756E6374696F6E286F626A65637429207B0A20202020202072657475726E20416E696D6174696F6E557064617465722E656C656D656E74732E70757368286F626A656374293B0A202020207D2C0A';
wwv_flow_api.g_varchar2_table(320) := '2020202072756E3A2066756E6374696F6E28666F72636529207B0A20202020202076617220656C656D2C2066696E69736865642C20697343616C6C6261636B2C206A2C206C656E2C207265663B0A20202020202069662028666F726365203D3D206E756C';
wwv_flow_api.g_varchar2_table(321) := '6C29207B0A2020202020202020666F726365203D2066616C73653B0A2020202020207D0A202020202020697343616C6C6261636B203D20697346696E697465287061727365466C6F617428666F72636529293B0A20202020202069662028697343616C6C';
wwv_flow_api.g_varchar2_table(322) := '6261636B207C7C20666F726365203D3D3D207472756529207B0A202020202020202066696E6973686564203D20747275653B0A2020202020202020726566203D20416E696D6174696F6E557064617465722E656C656D656E74733B0A2020202020202020';
wwv_flow_api.g_varchar2_table(323) := '666F7220286A203D20302C206C656E203D207265662E6C656E6774683B206A203C206C656E3B206A2B2B29207B0A20202020202020202020656C656D203D207265665B6A5D3B0A2020202020202020202069662028656C656D2E75706461746528666F72';
wwv_flow_api.g_varchar2_table(324) := '6365203D3D3D20747275652929207B0A20202020202020202020202066696E6973686564203D2066616C73653B0A202020202020202020207D0A20202020202020207D0A202020202020202072657475726E20416E696D6174696F6E557064617465722E';
wwv_flow_api.g_varchar2_table(325) := '616E696D4964203D2066696E6973686564203F206E756C6C203A2072657175657374416E696D6174696F6E4672616D6528416E696D6174696F6E557064617465722E72756E293B0A2020202020207D20656C73652069662028666F726365203D3D3D2066';
wwv_flow_api.g_varchar2_table(326) := '616C736529207B0A202020202020202069662028416E696D6174696F6E557064617465722E616E696D4964203D3D3D20216E756C6C29207B0A2020202020202020202063616E63656C416E696D6174696F6E4672616D6528416E696D6174696F6E557064';
wwv_flow_api.g_varchar2_table(327) := '617465722E616E696D4964293B0A20202020202020207D0A202020202020202072657475726E20416E696D6174696F6E557064617465722E616E696D4964203D2072657175657374416E696D6174696F6E4672616D6528416E696D6174696F6E55706461';
wwv_flow_api.g_varchar2_table(328) := '7465722E72756E293B0A2020202020207D0A202020207D0A20207D3B0A0A202069662028747970656F662077696E646F772E646566696E65203D3D3D202766756E6374696F6E27202626202877696E646F772E646566696E652E616D6420213D206E756C';
wwv_flow_api.g_varchar2_table(329) := '6C2929207B0A20202020646566696E652866756E6374696F6E2829207B0A20202020202072657475726E207B0A202020202020202047617567653A2047617567652C0A2020202020202020446F6E75743A20446F6E75742C0A2020202020202020426173';
wwv_flow_api.g_varchar2_table(330) := '65446F6E75743A2042617365446F6E75742C0A20202020202020205465787452656E64657265723A205465787452656E64657265720A2020202020207D3B0A202020207D293B0A20207D20656C73652069662028747970656F66206D6F64756C6520213D';
wwv_flow_api.g_varchar2_table(331) := '3D2027756E646566696E65642720262620286D6F64756C652E6578706F72747320213D206E756C6C2929207B0A202020206D6F64756C652E6578706F727473203D207B0A20202020202047617567653A2047617567652C0A202020202020446F6E75743A';
wwv_flow_api.g_varchar2_table(332) := '20446F6E75742C0A20202020202042617365446F6E75743A2042617365446F6E75742C0A2020202020205465787452656E64657265723A205465787452656E64657265720A202020207D3B0A20207D20656C7365207B0A2020202077696E646F772E4761';
wwv_flow_api.g_varchar2_table(333) := '756765203D2047617567653B0A2020202077696E646F772E446F6E7574203D20446F6E75743B0A2020202077696E646F772E42617365446F6E7574203D2042617365446F6E75743B0A2020202077696E646F772E5465787452656E6465726572203D2054';
wwv_flow_api.g_varchar2_table(334) := '65787452656E64657265723B0A20207D0A0A7D292E63616C6C2874686973293B0A';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(46130100074641674)
,p_plugin_id=>wwv_flow_api.id(27056297969156447474)
,p_file_name=>'apex_kpi_gauge.js'
,p_mime_type=>'application/x-javascript'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.import_end(p_auto_install_sup_obj => nvl(wwv_flow_application_install.get_auto_install_sup_obj, false), p_is_component_import => true);
commit;
end;
/
set verify on feedback on define on
prompt  ...done
